@@ -103,7 +103,8 @@ class csv2po:
             if comment in self.commentindex:
                 del self.commentindex[comment]
 
-    def convertunit(self, csvunit):
+    @staticmethod
+    def convertunit(csvunit):
         """converts csv unit to po unit"""
         pounit = po.pounit(encoding="UTF-8")
         if csvunit.location:
@@ -123,7 +124,7 @@ class csv2po:
             if len(thepolist) > 1:
                 csvfilename = getattr(self.csvfile, "filename", "(unknown)")
                 matches = "\n  ".join(
-                    ["possible match: " + pounit.source for pounit in thepolist]
+                    "possible match: " + pounit.source for pounit in thepolist
                 )
                 logger.warning(
                     "%s - csv entry not unique in pofile, "
