@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2003-2008 Zuza Software Foundation
 #
@@ -25,8 +24,6 @@ for examples and usage instructions.
 """
 
 import logging
-from six.moves.urllib import parse
-
 
 from translate.storage import oo, xliff
 
@@ -36,18 +33,20 @@ from translate.storage import oo, xliff
 logger = logging.getLogger(__name__)
 
 
-class oo2xliff(object):
-
-    def __init__(self, sourcelanguage, targetlanguage, blankmsgstr=False, long_keys=False):
+class oo2xliff:
+    def __init__(
+        self, sourcelanguage, targetlanguage, blankmsgstr=False, long_keys=False
+    ):
         """construct an oo2xliff converter for the specified languages"""
         self.sourcelanguage = sourcelanguage
         self.targetlanguage = targetlanguage
         self.blankmsgstr = blankmsgstr
         self.long_keys = long_keys
 
-    def maketargetunit(self, part1, part2, translators_comment, key, subkey):
+    @staticmethod
+    def maketargetunit(part1, part2, translators_comment, key, subkey):
         """makes a base unit (.po or XLIFF) out of a subkey of two parts"""
-        #TODO: Do better
+        # TODO: Do better
         text1 = getattr(part1, subkey)
         if text1 == "":
             return None
@@ -69,8 +68,10 @@ class oo2xliff(object):
         if self.sourcelanguage in theoo.languages:
             part1 = theoo.languages[self.sourcelanguage]
         else:
-            logging.error("/".join(theoo.lines[0].getkey()) +
-                          "language not found: %s", self.sourcelanguage)
+            logging.error(
+                "/".join(theoo.lines[0].getkey()) + "language not found: %s",
+                self.sourcelanguage,
+            )
             return []
         if self.blankmsgstr:
             # use a blank part2
@@ -98,16 +99,6 @@ class oo2xliff(object):
         thetargetfile = xliff.xlifffile()
         thetargetfile.setsourcelanguage(self.sourcelanguage)
         thetargetfile.settargetlanguage(self.targetlanguage)
-        # create a header for the file
-        bug_url = 'http://qa.openoffice.org/issues/enter_bug.cgi?%s' % \
-                  parse.urlencode({
-                      "subcomponent": "ui",
-                      "comment": "",
-                      "short_desc": "Localization issue in file: %s" %
-                                    theoofile.filename,
-                      "component": "l10n",
-                      "form_name": "enter_issue",
-                  })
         # go through the oo and convert each element
         for theoo in theoofile.units:
             unitlist = self.convertelement(theoo)
@@ -122,7 +113,16 @@ def verifyoptions(options):
         raise ValueError("You must specify the target language.")
 
 
-def convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None, targetlanguage=None, duplicatestyle="msgctxt", multifilestyle="single"):
+def convertoo(
+    inputfile,
+    outputfile,
+    templates,
+    pot=False,
+    sourcelanguage=None,
+    targetlanguage=None,
+    duplicatestyle="msgctxt",
+    multifilestyle="single",
+):
     """reads in stdin using inputstore class, converts using convertorclass, writes to stdout"""
     inputstore = oo.oofile()
     if hasattr(inputfile, "filename"):
@@ -138,18 +138,25 @@ def convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None,
         else:
             sourcelanguage = "en-US"
     if sourcelanguage not in inputstore.languages:
-        logger.warning("sourcelanguage '%s' not found in inputfile '%s' "
-                       "(contains %s)",
-                       sourcelanguage, inputfilename,
-                       ", ".join(inputstore.languages))
-    if not pot and (targetlanguage and
-                    targetlanguage not in inputstore.languages):
-        logger.warning("targetlanguage '%s' not found in inputfile '%s' "
-                       "(contains %s)",
-                       targetlanguage, inputfilename,
-                       ", ".join(inputstore.languages))
-    convertor = oo2xliff(sourcelanguage, targetlanguage, blankmsgstr=pot,
-                         long_keys=(multifilestyle != "single"))
+        logger.warning(
+            "sourcelanguage '%s' not found in inputfile '%s' " "(contains %s)",
+            sourcelanguage,
+            inputfilename,
+            ", ".join(inputstore.languages),
+        )
+    if not pot and (targetlanguage and targetlanguage not in inputstore.languages):
+        logger.warning(
+            "targetlanguage '%s' not found in inputfile '%s' " "(contains %s)",
+            targetlanguage,
+            inputfilename,
+            ", ".join(inputstore.languages),
+        )
+    convertor = oo2xliff(
+        sourcelanguage,
+        targetlanguage,
+        blankmsgstr=pot,
+        long_keys=(multifilestyle != "single"),
+    )
     outputstore = convertor.convertstore(inputstore, duplicatestyle)
     if outputstore.isempty():
         return 0
@@ -159,26 +166,42 @@ def convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None,
 
 def main(argv=None):
     from translate.convert import convert
-    formats = {
-        "oo": ("xlf", convertoo),
-        "sdf": ("xlf", convertoo),
-        "oo": ("xliff", convertoo),
-        "sdf": ("xliff", convertoo),
-    }
+
+    formats = (
+        ("oo", ("xlf", convertoo)),
+        ("sdf", ("xlf", convertoo)),
+        ("oo", ("xliff", convertoo)),
+        ("sdf", ("xliff", convertoo)),
+    )
     # always treat the input as an archive unless it is a directory
     archiveformats = {(None, "input"): oo.oomultifile}
-    parser = convert.ArchiveConvertOptionParser(formats, usepots=False,
-                                                description=__doc__,
-                                                archiveformats=archiveformats)
-    parser.add_option("-l", "--language", dest="targetlanguage", default=None,
-                      help="set target language to extract from oo file (e.g. af-ZA)",
-                      metavar="LANG")
+    parser = convert.ArchiveConvertOptionParser(
+        formats, usepots=False, description=__doc__, archiveformats=archiveformats
+    )
     parser.add_option(
-        "", "--source-language", dest="sourcelanguage", default=None,
-        help="set source language code (default en-US)", metavar="LANG")
-    parser.add_option("", "--nonrecursiveinput", dest="allowrecursiveinput",
-                      default=True, action="store_false",
-                      help="don't treat the input oo as a recursive store")
+        "-l",
+        "--language",
+        dest="targetlanguage",
+        default=None,
+        help="set target language to extract from oo file (e.g. af-ZA)",
+        metavar="LANG",
+    )
+    parser.add_option(
+        "",
+        "--source-language",
+        dest="sourcelanguage",
+        default=None,
+        help="set source language code (default en-US)",
+        metavar="LANG",
+    )
+    parser.add_option(
+        "",
+        "--nonrecursiveinput",
+        dest="allowrecursiveinput",
+        default=True,
+        action="store_false",
+        help="don't treat the input oo as a recursive store",
+    )
     parser.add_duplicates_option()
     parser.add_multifile_option()
     parser.passthrough.append("sourcelanguage")
@@ -187,5 +210,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
