@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2015 Zuza Software Foundation
 # Copyright 2015 Sarah Hale
@@ -18,15 +17,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-""" Tests converting Gettext PO localisation files to .Net Resource (.resx) files """
+"""Tests converting Gettext PO localisation files to .Net Resource (.resx) files"""
+
+from io import BytesIO
 
 from translate.convert import po2resx, test_convert
 from translate.storage import po
-from translate.misc import wStringIO
 
 
-class TestPO2RESX(object):
-    XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
+class TestPO2RESX:
+    XMLskeleton = """<?xml version="1.0" encoding="utf-8"?>
 <root>
   <xsd:schema xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata" id="root">
     <xsd:import namespace="http://www.w3.org/XML/1998/namespace" />
@@ -81,27 +81,34 @@ class TestPO2RESX(object):
     <value>2.0</value>
   </resheader>
   %s
-</root>'''
+</root>"""
 
-    def po2resx(self, resxsource, po_source):
-        """ Helper that merges po translations to .resx source without requiring files """
-        po_store = po.pofile(po_source.encode('utf-8'))
-        template_file = wStringIO.StringIO(resxsource)
+    @staticmethod
+    def po2resx(resxsource, po_source):
+        """Helper that merges po translations to .resx source without requiring files"""
+        po_store = po.pofile(po_source.encode("utf-8"))
+        template_file = BytesIO(resxsource.encode())
         convertor = po2resx.po2resx(template_file, po_store)
         output_resx = convertor.convertstore()
-        return output_resx.decode('utf-8')
+        return output_resx.decode("utf-8")
 
     def test_simpleunit(self):
-        """ Checks that a simple po entry definition converts properly to a resx entry """
+        """Checks that a simple po entry definition converts properly to a resx entry"""
         po_source = r'''#: key
 msgid "Source Text"
 msgstr "Some translated text"'''
-        resx_template = self.XMLskeleton % '''<data name="key" xml:space="preserve">
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="key" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % '''<data name="key" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="key" xml:space="preserve">
     <value>Some translated text</value>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
@@ -124,83 +131,113 @@ msgstr ""
 msgid "Applications"
 msgstr "Toepassings"
 """
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Toepassings</value>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_multiline(self):
-        """ Test multiline po entry """
+        """Test multiline po entry"""
         po_source = r'''#: ResourceKey
 msgid "First part "
 "and extra"
 msgstr "Eerste deel "
 "en ekstra"'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Eerste deel en ekstra</value>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_escapednewlines(self):
-        """ Test the escaping of newlines """
-        po_source = r'''#: ResourceKey
+        """Test the escaping of newlines"""
+        po_source = r"""#: ResourceKey
 msgid "First line\nSecond line"
 msgstr "Eerste lyn\nTweede lyn"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Eerste lyn
 Tweede lyn</value>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_escapedtabs(self):
-        """ Test the escaping of tabs """
-        po_source = r'''#: ResourceKey
+        """Test the escaping of tabs"""
+        po_source = r"""#: ResourceKey
 msgid "First column\tSecond column"
 msgstr "Eerste kolom\tTweede kolom"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Eerste kolom\tTweede kolom</value>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_escapedquotes(self):
-        """ Test the escaping of quotes (and slash) """
-        po_source = r'''#: ResourceKey
+        """Test the escaping of quotes (and slash)"""
+        po_source = r"""#: ResourceKey
 msgid "Hello \"Everyone\""
 msgstr "Good day \"All\""
 
 msgid "Use \\\"."
 msgstr "Gebruik \\\"."
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Good day "All"</value>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_exclusions(self):
-        """ Test that empty and fuzzy messages are excluded """
-        po_source = r'''#: ResourceKey
+        """Test that empty and fuzzy messages are excluded"""
+        po_source = r"""#: ResourceKey
 #, fuzzy
 msgid "One"
 msgstr "Een"
@@ -212,8 +249,10 @@ msgstr ""
 #: ResourceKey3
 msgid ""
 msgstr "Drie"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value />
   </data>
   <data name="ResourceKey2" xml:space="preserve">
@@ -221,8 +260,11 @@ msgstr "Drie"
   </data>
   <data name="ResourceKey3" xml:space="preserve">
     <value />
-  </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value />
   </data>
   <data name="ResourceKey2" xml:space="preserve">
@@ -230,226 +272,300 @@ msgstr "Drie"
   </data>
   <data name="ResourceKey3" xml:space="preserve">
     <value />
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments(self):
-        """ Tests that automatic comments are imported """
-        po_source = u'''#. This is a comment
+        """Tests that automatic comments are imported"""
+        po_source = """#. This is a comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is a comment</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments_existingcomment(self):
-        """ Tests a differing automatic comment is added if there is an existing automatic comment """
-        po_source = u'''#. This is a new comment
+        """Tests a differing automatic comment is added if there is an existing automatic comment"""
+        po_source = """#. This is a new comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment>This is an existing comment</comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 This is a new comment</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments_existingduplicatecomment(self):
-        """ Tests there is no duplication of automatic comments if it already exists and hasn't changed """
-        po_source = u'''#. This is an existing comment
+        """Tests there is no duplication of automatic comments if it already exists and hasn't changed"""
+        po_source = """#. This is an existing comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment>This is an existing comment</comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments_existingduplicatecommentwithwhitespace(self):
-        """ Tests there is no duplication of automatic comments if it already exists, hasn't changed but has leading or
-        trailing whitespaces """
-        po_source = u'''#.  This is an existing comment with leading and trailing spaces
+        """
+        Tests there is no duplication of automatic comments if it already
+        exists, hasn't changed but has leading or trailing whitespaces
+        """
+        po_source = """#.  This is an existing comment with leading and trailing spaces
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment> This is an existing comment with leading and trailing spaces </comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment with leading and trailing spaces</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_translatorcomments(self):
-        """ Tests that translator comments are imported """
-        po_source = u'''# This is a translator comment : 22.12.14
+        """Tests that translator comments are imported"""
+        po_source = """# This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>[Translator Comment: This is a translator comment : 22.12.14]</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_translatorcomments_existingcomment(self):
-        """ Tests a differing translator comment is added if there is an existing translator comment """
-        po_source = u'''# This is a new translator comment
+        """Tests a differing translator comment is added if there is an existing translator comment"""
+        po_source = """# This is a new translator comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment>[Translator Comment: This is an existing comment]</comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>[Translator Comment: This is an existing comment]
 [Translator Comment: This is a new translator comment]</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_translatorcomments_existingduplicatecomment(self):
-        """ Tests there is no duplication of translator comments if it already exists and hasn't changed """
-        po_source = u'''# This is an existing translator comment
+        """Tests there is no duplication of translator comments if it already exists and hasn't changed"""
+        po_source = """# This is an existing translator comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment>[Translator Comment: This is an existing translator comment]</comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>[Translator Comment: This is an existing translator comment]</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_combocomments(self):
-        """ Tests that translator comments and automatic comments are imported """
-        po_source = u'''#. This is a developer comment
+        """Tests that translator comments and automatic comments are imported"""
+        po_source = """#. This is a developer comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is a developer comment
 [Translator Comment: This is a translator comment : 22.12.14]</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_combocomments_existingduplicatecomment(self):
-        """ Tests there is no duplication of automatic comment if it already exists and hasn't changed, but still adds
-        the translator comment """
-        po_source = u'''#. This is an existing comment
+        """
+        Tests there is no duplication of automatic comment if it already exists
+        and hasn't changed, but still adds the translator comment
+        """
+        po_source = """#. This is an existing comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment>This is an existing comment</comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 [Translator Comment: This is a translator comment : 22.12.14]</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_combocomments_existingcomment(self):
-        """ Tests a differing automatic comment is added if there is an existing automatic comment, but still adds
-        the translator comment """
-        po_source = u'''#. This is a new comment
+        """
+        Tests a differing automatic comment is added if there is an existing
+        automatic comment, but still adds the translator comment
+        """
+        po_source = """#. This is a new comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment>This is an existing comment</comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 This is a new comment
 [Translator Comment: This is a translator comment : 22.12.14]</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_existingcomments(self):
-        """ Tests that no extra space is added when there are no changes to existing comments"""
-        po_source = u'''#. This is an existing comment
+        """Tests that no extra space is added when there are no changes to existing comments"""
+        po_source = """#. This is an existing comment
 # This is an existing translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
+"""
+        resx_template = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value></value>
     <comment>This is an existing comment
 [Translator Comment: This is an existing translator comment : 22.12.14]</comment>
-  </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+  </data>"""
+        )
+        expected_output = (
+            self.XMLskeleton
+            % """<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 [Translator Comment: This is an existing translator comment : 22.12.14]</comment>
-  </data>'''
+  </data>"""
+        )
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
 
 class TestPO2RESXCommand(test_convert.TestConvertCommand, TestPO2RESX):
-    """ Tests running actual po2resx commands on files """
+    """Tests running actual po2resx commands on files"""
+
     convertmodule = po2resx
 
     def test_help(self, capsys):
-        """ Tests getting help """
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
+        """Tests getting help"""
+        options = super().test_help(capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
