@@ -1,4 +1,3 @@
-import warnings
 from io import BytesIO
 
 from pytest import mark
@@ -8,13 +7,8 @@ from translate.storage import po
 
 
 class TestPOT2PO:
-    def setup_method(self, method):
-        warnings.resetwarnings()
-
-    def teardown_method(self, method):
-        warnings.resetwarnings()
-
-    def convertpot(self, potsource, posource=None):
+    @staticmethod
+    def convertpot(potsource, posource=None):
         """helper that converts pot source to po source without requiring files"""
         potfile = BytesIO(potsource.encode())
         if posource:
@@ -26,7 +20,8 @@ class TestPOT2PO:
         pooutfile.seek(0)
         return po.pofile(pooutfile.read())
 
-    def singleunit(self, pofile):
+    @staticmethod
+    def singleunit(pofile):
         """checks that the pofile contains a single non-header unit, and returns it"""
         assert len(pofile.units) == 2
         assert pofile.units[0].isheader()
@@ -835,7 +830,7 @@ class TestPOT2POCommand(test_convert.TestConvertCommand, TestPOT2PO):
 
     def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
+        options = super().test_help(capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--tm")
