@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2009 Zuza Software Foundation
 #
@@ -26,9 +25,9 @@ for examples and usage instructions.
 from translate.storage import po, xliff
 
 
-class xliff2po(object):
-
-    def converttransunit(self, transunit):
+class xliff2po:
+    @staticmethod
+    def converttransunit(transunit):
         """makes a pounit from the given transunit"""
         thepo = po.pounit()
 
@@ -72,14 +71,18 @@ class xliff2po(object):
         for transunit in XliffFile.units:
             if transunit.isheader():
                 thetargetfile.updateheader(add=True, **XliffFile.parseheader())
-                if transunit.getnotes('translator'):
-                    targetheader.addnote(transunit.getnotes('translator'),
-                                         origin='translator',
-                                         position='replace')
-                if transunit.getnotes('developer'):
-                    targetheader.addnote(transunit.getnotes('developer'),
-                                         origin='developer',
-                                         position='replace')
+                if transunit.getnotes("translator"):
+                    targetheader.addnote(
+                        transunit.getnotes("translator"),
+                        origin="translator",
+                        position="replace",
+                    )
+                if transunit.getnotes("developer"):
+                    targetheader.addnote(
+                        transunit.getnotes("developer"),
+                        origin="developer",
+                        position="replace",
+                    )
                 targetheader.markfuzzy(transunit.isfuzzy())
                 continue
             thepo = self.converttransunit(transunit)
@@ -102,11 +105,11 @@ def convertxliff(inputfile, outputfile, templates, duplicatestyle="msgctxt"):
 
 def main(argv=None):
     from translate.convert import convert
+
     formats = {
         "xlf": ("po", convertxliff),
         "xliff": ("po", convertxliff),
     }
-    parser = convert.ConvertOptionParser(formats, usepots=True,
-                                         description=__doc__)
+    parser = convert.ConvertOptionParser(formats, usepots=True, description=__doc__)
     parser.add_duplicates_option()
     parser.run(argv)
