@@ -131,7 +131,7 @@ def filtervariables(startmarker, endmarker, varfilter):
         startmarkerlen = len(startmarker)
     if endmarker is None:
         endmarkerlen = 0
-    elif type(endmarker) == int:
+    elif type(endmarker) is int:
         endmarkerlen = 0
     else:
         endmarkerlen = len(endmarker)
