@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -19,10 +18,9 @@
 
 """This module represents the Amharic language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Amharic_language
+.. seealso:: :wp:`Amharic_language`
 """
 
-from __future__ import unicode_literals
 
 import re
 
@@ -36,11 +34,15 @@ class am(common.Common):
 
     sentenceend = "።!?…"
 
-    sentencere = re.compile(r"""(?s)    #make . also match newlines
+    sentencere = re.compile(
+        r"""(?s)    #make . also match newlines
                             .*?         #anything, but match non-greedy
                             [%s]        #the puntuation for sentence ending
                             \s*         #optional spacing after the puntuation
-                            """ % sentenceend, re.VERBOSE)
+                            """
+        % sentenceend,
+        re.VERBOSE,
+    )
 
     puncdict = {
         ".": "።",
@@ -49,5 +51,5 @@ class am(common.Common):
     }
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
