@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -20,9 +18,10 @@
 
 """This module represents the Azerbaijani language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Azerbaijani_language
+.. seealso:: :wp:`Azerbaijani_language`
 """
 
+
 from translate.lang import common
 
 
