@@ -29,10 +29,10 @@ from translate.storage import base
 class DefaultDialect(csv.excel):
     skipinitialspace = True
     quoting = csv.QUOTE_ALL
-    escapechar = '\\'
+    escapechar = "\\"
 
 
-csv.register_dialect('default', DefaultDialect)
+csv.register_dialect("default", DefaultDialect)
 
 
 class csvunit(base.TranslationUnit):
@@ -44,7 +44,7 @@ class csvunit(base.TranslationUnit):
         self.source = source or ""
         self.target = ""
         self.id = ""
-        self.fuzzy = 'False'
+        self.fuzzy = "False"
         self.developer_comments = ""
         self.translator_comments = ""
         self.context = ""
@@ -56,7 +56,7 @@ class csvunit(base.TranslationUnit):
         result = self.source
         context = self.context
         if context:
-            result = "%s\04%s" % (context, result)
+            result = f"{context}\04{result}"
 
         return result
 
@@ -64,7 +64,7 @@ class csvunit(base.TranslationUnit):
         self.id = value
 
     def getlocations(self):
-        #FIXME: do we need to support more than one location
+        # FIXME: do we need to support more than one location
         return [self.location]
 
     def addlocation(self, location):
@@ -81,46 +81,46 @@ class csvunit(base.TranslationUnit):
             result = self.translator_comments
             if self.developer_comments:
                 if result:
-                    result += '\n' + self.developer_comments
+                    result += "\n" + self.developer_comments
                 else:
                     result = self.developer_comments
             return result
         elif origin == "translator":
             return self.translator_comments
-        elif origin in ('programmer', 'developer', 'source code'):
+        elif origin in ("programmer", "developer", "source code"):
             return self.developer_comments
         else:
             raise ValueError("Comment type not valid")
 
     def addnote(self, text, origin=None, position="append"):
-        if origin in ('programmer', 'developer', 'source code'):
-            if position == 'append' and self.developer_comments:
-                self.developer_comments += '\n' + text
-            elif position == 'prepend' and self.developer_comments:
-                self.developer_comments = text + '\n' + self.developer_comments
+        if origin in ("programmer", "developer", "source code"):
+            if position == "append" and self.developer_comments:
+                self.developer_comments += "\n" + text
+            elif position == "prepend" and self.developer_comments:
+                self.developer_comments = text + "\n" + self.developer_comments
             else:
                 self.developer_comments = text
         else:
-            if position == 'append' and self.translator_comments:
-                self.translator_comments += '\n' + text
-            elif position == 'prepend' and self.translator_comments:
-                self.translator_comments = self.translator_comments + '\n' + text
+            if position == "append" and self.translator_comments:
+                self.translator_comments += "\n" + text
+            elif position == "prepend" and self.translator_comments:
+                self.translator_comments = self.translator_comments + "\n" + text
             else:
                 self.translator_comments = text
 
     def removenotes(self, origin=None):
-        self.translator_comments = ''
+        self.translator_comments = ""
 
     def isfuzzy(self):
-        if self.fuzzy.lower() in ('1', 'x', 'true', 'yes', 'fuzzy'):
+        if self.fuzzy.lower() in ("1", "x", "true", "yes", "fuzzy"):
             return True
         return False
 
     def markfuzzy(self, value=True):
         if value:
-            self.fuzzy = 'True'
+            self.fuzzy = "True"
         else:
-            self.fuzzy = 'False'
+            self.fuzzy = "False"
 
     def match_header(self):
         """see if unit might be a header"""
@@ -128,7 +128,7 @@ class csvunit(base.TranslationUnit):
         for key, value in self.todict().items():
             if value:
                 some_value = True
-            if key.lower() != 'fuzzy' and value and key.lower() != value.lower():
+            if key.lower() != "fuzzy" and value and key.lower() != value.lower():
                 return False
         return some_value
 
@@ -150,7 +150,7 @@ class csvunit(base.TranslationUnit):
                 target = target.replace(escaped, unescaped, 1)
         return source, target
 
-    def fromdict(self, cedict, encoding='utf-8'):
+    def fromdict(self, cedict, encoding="utf-8"):
         for key, value in cedict.items():
             rkey = fieldname_map.get(key, key)
             if value is None or key is None or key == EXTRA_KEY:
@@ -172,73 +172,72 @@ class csvunit(base.TranslationUnit):
             elif rkey == "developer_comments":
                 self.developer_comments = value
 
-        #self.source, self.target = self.remove_spreadsheet_escapes(self.source, self.target)
+        # self.source, self.target = self.remove_spreadsheet_escapes(self.source, self.target)
 
     def todict(self, **kwargs):
-        #FIXME: use apis?
-        #source, target = self.add_spreadsheet_escapes(self.source, self.target)
-        source = self.source
-        target = self.target
-        output = {
-            'location': self.location,
-            'source': source,
-            'target': target,
-            'id': self.id,
-            'fuzzy': str(self.fuzzy),
-            'context': self.context,
-            'translator_comments': self.translator_comments,
-            'developer_comments': self.developer_comments,
+        # FIXME: use apis?
+        # source, target = self.add_spreadsheet_escapes(self.source, self.target)
+        return {
+            "location": self.location,
+            "source": self.source,
+            "target": self.target,
+            "id": self.id,
+            "fuzzy": str(self.fuzzy),
+            "context": self.context,
+            "translator_comments": self.translator_comments,
+            "developer_comments": self.developer_comments,
         }
 
-        return output
-
     def __str__(self):
         return str(self.todict())
 
 
 fieldname_map = {
-    'original': 'source',
-    'untranslated': 'source',
-    'translated': 'target',
-    'translation': 'target',
-    'identified': 'id',
-    'key': 'id',
-    'label': 'id',
-    'translator comments': 'translator_comments',
-    'notes': 'translator_comments',
-    'developer comments': 'developer_comments',
-    'state': 'fuzzy',
+    "original": "source",
+    "untranslated": "source",
+    "translated": "target",
+    "translation": "target",
+    "identified": "id",
+    "key": "id",
+    "label": "id",
+    "translator comments": "translator_comments",
+    "notes": "translator_comments",
+    "developer comments": "developer_comments",
+    "state": "fuzzy",
 }
 
 
-EXTRA_KEY = '__CSVL10N__EXTRA__'
+EXTRA_KEY = "__CSVL10N__EXTRA__"
 
 
 def try_dialects(inputfile, fieldnames, dialect):
-    #FIXME: does it verify at all if we don't actually step through the file?
+    # FIXME: does it verify at all if we don't actually step through the file?
     try:
         inputfile.seek(0)
-        reader = csv.DictReader(inputfile, fieldnames=fieldnames, dialect=dialect, restkey=EXTRA_KEY)
+        return csv.DictReader(
+            inputfile, fieldnames=fieldnames, dialect=dialect, restkey=EXTRA_KEY
+        )
     except csv.Error:
         try:
             inputfile.seek(0)
-            reader = csv.DictReader(inputfile, fieldnames=fieldnames, dialect='default', restkey=EXTRA_KEY)
+            return csv.DictReader(
+                inputfile, fieldnames=fieldnames, dialect="default", restkey=EXTRA_KEY
+            )
         except csv.Error:
             inputfile.seek(0)
-            reader = csv.DictReader(inputfile, fieldnames=fieldnames, dialect='excel', restkey=EXTRA_KEY)
-    return reader
+            return csv.DictReader(
+                inputfile, fieldnames=fieldnames, dialect="excel", restkey=EXTRA_KEY
+            )
 
 
 def valid_fieldnames(fieldnames):
     """Check if fieldnames are valid, that is at least one field is identified
     as the source.
     """
-    for fieldname in fieldnames:
-        if fieldname == 'source':
-            return True
-        elif fieldname in fieldname_map and fieldname_map[fieldname] == 'source':
-            return True
-    return False
+    return any(
+        fieldname == "source" or fieldname_map.get(fieldname) == "source"
+        for fieldname in fieldnames
+    )
 
 
 def detect_header(inputfile, dialect, fieldnames):
@@ -248,10 +247,10 @@ def detect_header(inputfile, dialect, fieldnames):
     except csv.Error:
         try:
             inputfile.seek(0)
-            reader = csv.reader(inputfile, 'default')
+            reader = csv.reader(inputfile, "default")
         except csv.Error:
             inputfile.seek(0)
-            reader = csv.reader(inputfile, 'excel')
+            reader = csv.reader(inputfile, "excel")
 
     header = next(reader)
     columncount = max(len(header), 3)
@@ -267,26 +266,37 @@ class csvfile(base.TranslationStore):
 
     UnitClass = csvunit
     Name = "Comma Separated Value"
-    Mimetypes = ['text/comma-separated-values', 'text/csv']
+    Mimetypes = ["text/comma-separated-values", "text/csv"]
     Extensions = ["csv"]
 
-    def __init__(self, inputfile=None, fieldnames=None, encoding='auto'):
+    def __init__(self, inputfile=None, fieldnames=None, encoding="auto"):
         super().__init__(encoding=encoding)
         if not fieldnames:
-            self.fieldnames = ['location', 'source', 'target', 'id', 'fuzzy', 'context', 'translator_comments', 'developer_comments']
+            self.fieldnames = [
+                "location",
+                "source",
+                "target",
+                "id",
+                "fuzzy",
+                "context",
+                "translator_comments",
+                "developer_comments",
+            ]
         else:
             self.fieldnames = fieldnames
-        self.filename = getattr(inputfile, 'name', '')
-        self.dialect = 'default'
+        self.filename = getattr(inputfile, "name", "")
+        self.dialect = "default"
         if inputfile is not None:
             csvsrc = inputfile.read()
             inputfile.close()
             self.parse(csvsrc)
 
     def parse(self, csvsrc, sample_length=1024):
-        text, encoding = self.detect_encoding(csvsrc, default_encodings=['utf-8', 'utf-16'])
-        #FIXME: raise parse error if encoding detection fails?
-        self.encoding = encoding or 'utf-8'
+        text, encoding = self.detect_encoding(
+            csvsrc, default_encodings=["utf-8", "utf-16"]
+        )
+        # FIXME: raise parse error if encoding detection fails?
+        self.encoding = encoding or "utf-8"
 
         sniffer = csv.Sniffer()
         if sample_length:
@@ -297,11 +307,11 @@ class csvfile(base.TranslationStore):
         try:
             self.dialect = sniffer.sniff(sample)
             if self.dialect.quoting == csv.QUOTE_MINIMAL:
-                #HACKISH: most probably a default, not real detection
+                # HACKISH: most probably a default, not real detection
                 self.dialect.quoting = csv.QUOTE_ALL
                 self.dialect.doublequote = True
         except csv.Error:
-            self.dialect = 'default'
+            self.dialect = "default"
 
         inputfile = csv.StringIO(text)
         try:
@@ -332,9 +342,9 @@ class csvfile(base.TranslationStore):
 
     def getoutput(self):
         output = csv.StringIO()
-        writer = csv.DictWriter(output, self.fieldnames,
-                                extrasaction='ignore',
-                                dialect=self.dialect)
+        writer = csv.DictWriter(
+            output, self.fieldnames, extrasaction="ignore", dialect=self.dialect
+        )
         writer.writeheader()
         for ce in self.units:
             writer.writerow(ce.todict())
