@@ -105,7 +105,7 @@ def quoteforandroid(source):
     # Replace "'" character with the \u0027 escape. Other possible replaces are
     # "\\&apos;" or "\\'".
     source = source.replace("'", "\\u0027")
-    source = source.replace("\"", "\\&quot;")
+    source = source.replace('"', "\\&quot;")
     value = quotefordtd(source)  # value is an UTF-8 encoded string.
     return value
 
@@ -116,15 +116,15 @@ def unquotefromandroid(source):
     value = value.replace("\\&apos;", "'")
     value = value.replace("\\'", "'")
     value = value.replace("\\u0027", "'")
-    value = value.replace("\\\"", "\"")  # This converts \&quot; to ".
+    value = value.replace('\\"', '"')  # This converts \&quot; to ".
     return value
 
 
 _DTD_CODEPOINT2NAME = {
     ord("%"): "#037",  # Always escape % sign as &#037;.
     ord("&"): "amp",
-    #ord("<"): "lt",  # Not really so useful.
-    #ord(">"): "gt",  # Not really so useful.
+    # ord("<"): "lt",  # Not really so useful.
+    # ord(">"): "gt",  # Not really so useful.
 }
 
 
@@ -134,20 +134,20 @@ def quotefordtd(source):
     if '"' in source:
         source = source.replace("'", "&apos;")  # This seems not to runned.
         if '="' not in source:  # Avoid escaping " chars in href attributes.
-            source = source.replace("\"", "&quot;")
-            value = "\"" + source + "\""  # Quote using double quotes.
+            source = source.replace('"', "&quot;")
+            value = '"' + source + '"'  # Quote using double quotes.
         else:
             value = "'" + source + "'"  # Quote using single quotes.
     else:
-        value = "\"" + source + "\""  # Quote using double quotes.
+        value = '"' + source + '"'  # Quote using double quotes.
     return value
 
 
 _DTD_NAME2CODEPOINT = {
     "quot": ord('"'),
     "amp": ord("&"),
-    #"lt": ord("<"),  # Not really so useful.
-    #"gt": ord(">"),  # Not really so useful.
+    # "lt": ord("<"),  # Not really so useful.
+    # "gt": ord(">"),  # Not really so useful.
     # FIXME these should probably be handled in a more general way
     "#x0022": ord('"'),
     "#187": ord("»"),
@@ -165,13 +165,12 @@ def unquotefromdtd(source):
     # The quote characters should be the first and last characters in the
     # string. Of course there could also be quote characters within the string.
     quotechar = source[0]
-    extracted, quotefinished = quote.extractwithoutquotes(source, quotechar, quotechar, allowreentry=False)
-    if isinstance(extracted, bytes):
-        extracted = extracted.decode('utf-8')
+    extracted, quotefinished = quote.extractwithoutquotes(
+        source, quotechar, quotechar, allowreentry=False
+    )
     if quotechar == "'":
         extracted = extracted.replace("&apos;", "'")
-    extracted = quote.entitydecode(extracted, _DTD_NAME2CODEPOINT)
-    return extracted
+    return quote.entitydecode(extracted, _DTD_NAME2CODEPOINT)
 
 
 def removeinvalidamps(name, value):
@@ -194,9 +193,9 @@ def removeinvalidamps(name, value):
 
     def is_valid_entity_name(name):
         """Check that supplied *name* is a valid entity name."""
-        if name.replace('.', '').replace('_', '').isalnum():
+        if name.replace(".", "").replace("_", "").isalnum():
             return True
-        elif name[0] == '#' and name[1:].isalnum():
+        elif name[0] == "#" and name[1:].isalnum():
             return True
         return False
 
@@ -207,15 +206,14 @@ def removeinvalidamps(name, value):
         if amppos != -1:
             amppos += 1
             semipos = value.find(";", amppos)
-            if semipos != -1:
-                if is_valid_entity_name(value[amppos:semipos]):
-                    continue
+            if semipos != -1 and is_valid_entity_name(value[amppos:semipos]):
+                continue
             invalid_amps.append(amppos - 1)
     if len(invalid_amps) > 0:
         warnings.warn("invalid ampersands in dtd entity %s" % (name))
         adjustment = 0
         for amppos in invalid_amps:
-            value = value[:amppos-adjustment] + value[amppos-adjustment+1:]
+            value = value[: amppos - adjustment] + value[amppos - adjustment + 1 :]
             adjustment += 1
     return value
 
@@ -234,8 +232,8 @@ class dtdunit(base.TranslationUnit):
         self.inentity = False
         self.entity = "FakeEntityOnlyForInitialisationAndTesting"
         self.source = source
-        self.space_pre_entity = ' '
-        self.space_pre_definition = ' '
+        self.space_pre_entity = " "
+        self.space_pre_definition = " "
         self.closing = ">"
 
     # Note that source and target are equivalent for monolingual units
@@ -261,8 +259,7 @@ class dtdunit(base.TranslationUnit):
         """gets the unquoted target string"""
         if self.android:
             return unquotefromandroid(self.definition)
-        else:
-            return unquotefromdtd(self.definition)
+        return unquotefromdtd(self.definition)
 
     @target.setter
     def target(self, target):
@@ -315,7 +312,7 @@ class dtdunit(base.TranslationUnit):
         # self._locnotes = []
         # self.comments = []
         self.entity = None
-        self.definition = ''
+        self.definition = ""
         if not dtdsrc:
             return 0
         lines = dtdsrc.split("\n")
@@ -325,27 +322,27 @@ class dtdunit(base.TranslationUnit):
             line += "\n"
             linesprocessed += 1
             if not self.incomment:
-                if (line.find('<!--') != -1):
+                if line.find("<!--") != -1:
                     self.incomment = True
                     self.continuecomment = False
                     # now work out the type of comment, and save it (remember we're not in the comment yet)
                     (comment, dummy) = quote.extract(line, "<!--", "-->", None, 0)
-                    if comment.find('LOCALIZATION NOTE') != -1:
-                        l = quote.findend(comment, 'LOCALIZATION NOTE')
-                        while (comment[l] == ' '):
+                    if comment.find("LOCALIZATION NOTE") != -1:
+                        l = quote.findend(comment, "LOCALIZATION NOTE")
+                        while comment[l] == " ":
                             l += 1
-                        if comment.find('FILE', l) == l:
+                        if comment.find("FILE", l) == l:
                             self.commenttype = "locfile"
-                        elif comment.find('BEGIN', l) == l:
+                        elif comment.find("BEGIN", l) == l:
                             self.commenttype = "locgroupstart"
-                        elif comment.find('END', l) == l:
+                        elif comment.find("END", l) == l:
                             self.commenttype = "locgroupend"
                         else:
                             self.commenttype = "locnote"
                     else:
                         # plain comment
                         self.commenttype = "comment"
-                #FIXME: bloody entity might share a line with something important
+                # FIXME: bloody entity might share a line with something important
                 elif not self.inentity and re.search("%.*;", line):
                     # now work out the type of comment, and save it (remember we're not in the comment yet)
                     self.comments.append(("comment", line))
@@ -354,7 +351,9 @@ class dtdunit(base.TranslationUnit):
 
             if self.incomment:
                 # some kind of comment
-                (comment, self.incomment) = quote.extract(line, "<!--", "-->", None, self.continuecomment)
+                (comment, self.incomment) = quote.extract(
+                    line, "<!--", "-->", None, self.continuecomment
+                )
                 self.continuecomment = self.incomment
                 # strip the comment out of what will be parsed
                 line = line.replace(comment, "", 1)
@@ -362,9 +361,9 @@ class dtdunit(base.TranslationUnit):
                 if not self.incomment:
                     if line.isspace():
                         comment += line
-                        line = ''
+                        line = ""
                     else:
-                        comment += '\n'
+                        comment += "\n"
                 # check if there's actually an entity definition that's commented out
                 # TODO: parse these, store as obsolete messages
                 # if comment.find('<!ENTITY') != -1:
@@ -385,7 +384,7 @@ class dtdunit(base.TranslationUnit):
                     self.comments.append(commentpair)
 
             if not self.inentity and not self.incomment:
-                entitypos = line.find('<!ENTITY')
+                entitypos = line.find("<!ENTITY")
                 if entitypos != -1:
                     self.inentity = True
                     beforeentity = line[:entitypos].strip()
@@ -398,33 +397,33 @@ class dtdunit(base.TranslationUnit):
             if self.inentity:
                 if self.entitypart == "start":
                     # the entity definition
-                    e = quote.findend(line, '<!ENTITY')
+                    e = quote.findend(line, "<!ENTITY")
                     line = line[e:]
                     self.entitypart = "name"
                     self.entitytype = "internal"
                 if self.entitypart == "name":
                     s = 0
                     e = 0
-                    while (e < len(line) and line[e].isspace()):
+                    while e < len(line) and line[e].isspace():
                         e += 1
-                    self.space_pre_entity = ' ' * (e - s)
+                    self.space_pre_entity = " " * (e - s)
                     s = e
-                    self.entity = ''
-                    if (e < len(line) and line[e] == '%'):
+                    self.entity = ""
+                    if e < len(line) and line[e] == "%":
                         self.entitytype = "external"
                         self.entityparameter = ""
                         e += 1
-                        while (e < len(line) and line[e].isspace()):
+                        while e < len(line) and line[e].isspace():
                             e += 1
-                    while (e < len(line) and not line[e].isspace()):
+                    while e < len(line) and not line[e].isspace():
                         self.entity += line[e]
                         e += 1
                     s = e
 
                     assert quote.rstripeol(self.entity) == self.entity
-                    while (e < len(line) and line[e].isspace()):
+                    while e < len(line) and line[e].isspace():
                         e += 1
-                    self.space_pre_definition = ' ' * (e - s)
+                    self.space_pre_definition = " " * (e - s)
                     if self.entity:
                         if self.entitytype == "external":
                             self.entitypart = "parameter"
@@ -439,13 +438,13 @@ class dtdunit(base.TranslationUnit):
                             self.entityhelp = (e, line[e])
                             self.instring = False
                 if self.entitypart == "parameter":
-                    while (e < len(line) and line[e].isspace()):
+                    while e < len(line) and line[e].isspace():
                         e += 1
                     paramstart = e
-                    while (e < len(line) and line[e].isalnum()):
+                    while e < len(line) and line[e].isalnum():
                         e += 1
                     self.entityparameter += line[paramstart:e]
-                    while (e < len(line) and line[e].isspace()):
+                    while e < len(line) and line[e].isspace():
                         e += 1
                     line = line[e:]
                     e = 0
@@ -458,7 +457,7 @@ class dtdunit(base.TranslationUnit):
                 if self.entitypart == "definition":
                     if self.entityhelp is None:
                         e = 0
-                        while (e < len(line) and line[e].isspace()):
+                        while e < len(line) and line[e].isspace():
                             e += 1
                         if e == len(line):
                             continue
@@ -466,17 +465,31 @@ class dtdunit(base.TranslationUnit):
                         self.instring = False
                     # actually the lines below should remember instring, rather than using it as dummy
                     e = self.entityhelp[0]
-                    if (self.entityhelp[1] == "'"):
-                        (defpart, self.instring) = quote.extract(line[e:], "'", "'", startinstring=self.instring, allowreentry=False)
-                    elif (self.entityhelp[1] == '"'):
-                        (defpart, self.instring) = quote.extract(line[e:], '"', '"', startinstring=self.instring, allowreentry=False)
+                    if self.entityhelp[1] == "'":
+                        (defpart, self.instring) = quote.extract(
+                            line[e:],
+                            "'",
+                            "'",
+                            startinstring=self.instring,
+                            allowreentry=False,
+                        )
+                    elif self.entityhelp[1] == '"':
+                        (defpart, self.instring) = quote.extract(
+                            line[e:],
+                            '"',
+                            '"',
+                            startinstring=self.instring,
+                            allowreentry=False,
+                        )
                     else:
-                        raise ValueError("Unexpected quote character... %r" % (self.entityhelp[1]))
+                        raise ValueError(
+                            "Unexpected quote character... %r" % (self.entityhelp[1])
+                        )
                     # for any following lines, start at the beginning of the line. remember the quote character
                     self.entityhelp = (0, self.entityhelp[1])
                     self.definition += defpart
                     if not self.instring:
-                        self.closing = line[e+len(defpart):].rstrip("\n\r")
+                        self.closing = line[e + len(defpart) :].rstrip("\n\r")
                         self.inentity = False
                         break
 
@@ -499,13 +512,28 @@ class dtdunit(base.TranslationUnit):
         # for gs in self._locgroupstarts: yield gs
         # for n in self._locnotes: yield n
         if len(self.entity) > 0:
-            if getattr(self, 'entitytype', None) == 'external':
-                entityline = '<!ENTITY % ' + self.entity + ' ' + self.entityparameter + ' ' + self.definition + self.closing
+            if getattr(self, "entitytype", None) == "external":
+                entityline = (
+                    "<!ENTITY % "
+                    + self.entity
+                    + " "
+                    + self.entityparameter
+                    + " "
+                    + self.definition
+                    + self.closing
+                )
             else:
-                entityline = '<!ENTITY' + self.space_pre_entity + self.entity + self.space_pre_definition + self.definition + self.closing
-            if getattr(self, 'hashprefix', None):
+                entityline = (
+                    "<!ENTITY"
+                    + self.space_pre_entity
+                    + self.entity
+                    + self.space_pre_definition
+                    + self.definition
+                    + self.closing
+                )
+            if getattr(self, "hashprefix", None):
                 entityline = self.hashprefix + " " + entityline
-            lines.append(entityline + '\n')
+            lines.append(entityline + "\n")
         return "".join(lines)
 
 
@@ -517,7 +545,7 @@ class dtdfile(base.TranslationStore):
     def __init__(self, inputfile=None, android=False):
         """construct a dtdfile, optionally reading in from inputfile"""
         super().__init__()
-        self.filename = getattr(inputfile, 'name', '')
+        self.filename = getattr(inputfile, "name", "")
         self.android = android
         if inputfile is not None:
             dtdsrc = inputfile.read()
@@ -529,15 +557,15 @@ class dtdfile(base.TranslationStore):
         end = 0
         lines = dtdsrc.split(b"\n")
         while end < len(lines):
-            if (start == end):
+            if start == end:
                 end += 1
             foundentity = False
             while end < len(lines):
                 if end >= len(lines):
                     break
-                if lines[end].find(b'<!ENTITY') > -1:
+                if lines[end].find(b"<!ENTITY") > -1:
                     foundentity = True
-                if foundentity and re.match(br"[\"']\s*>", lines[end]):
+                if foundentity and re.match(rb"[\"']\s*>", lines[end]):
                     end += 1
                     break
                 end += 1
@@ -546,16 +574,23 @@ class dtdfile(base.TranslationStore):
             while linesprocessed >= 1:
                 newdtd = dtdunit(android=self.android)
                 try:
-                    linesprocessed = newdtd.parse((b"\n".join(lines[start:end])).decode(self.encoding))
-                    if linesprocessed >= 1 and (not newdtd.isblank() or newdtd.unparsedlines):
+                    linesprocessed = newdtd.parse(
+                        (b"\n".join(lines[start:end])).decode(self.encoding)
+                    )
+                    if linesprocessed >= 1 and (
+                        not newdtd.isblank() or newdtd.unparsedlines
+                    ):
                         self.units.append(newdtd)
                 except Exception as e:
-                    warnings.warn("%s\nError occured between lines %d and %d:\n%s" % (e, start + 1, end, b"\n".join(lines[start:end])))
+                    warnings.warn(
+                        "%s\nError occured between lines %d and %d:\n%s"
+                        % (e, start + 1, end, b"\n".join(lines[start:end]))
+                    )
                 start += linesprocessed
 
     def serialize(self, out):
         """Write content to file"""
-        content = b''
+        content = b""
         for dtd in self.units:
             unit_str = str(dtd).encode(self.encoding)
             out.write(unit_str)
