@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -28,6 +26,7 @@ from translate.storage.placeables.strelem import StringElem
 
 class BasePlaceable(StringElem):
     """Base class for all placeables."""
+
     parse = None
 
 
@@ -47,9 +46,9 @@ class SubflowPlaceable(BasePlaceable):
     pass
 
 
-class Delimiter(object):
+class Delimiter:
     pass
 
 
-class PairedDelimiter(object):
+class PairedDelimiter:
     pass
