@@ -130,6 +130,7 @@ import collections
 import re
 from codecs import iterencode
 from copy import deepcopy
+from typing import List
 
 from lxml import etree
 
@@ -254,14 +255,15 @@ class Dialect:
 
     name = None
     default_encoding = "iso-8859-1"
-    delimiters = None
+    delimiters: List[str] = []
     pair_terminator = ""
     key_wrap_char = ""
     value_wrap_char = ""
     drop_comments = []
+    has_plurals = False
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         """Encode the string"""
         # FIXME: dialects are a bad idea, not possible for subclasses
         # to override key methods
@@ -269,8 +271,8 @@ class Dialect:
             return quote.javapropertiesencode(string or "")
         return quote.java_utf8_properties_encode(string or "")
 
-    @classmethod
-    def decode(cls, string):
+    @staticmethod
+    def decode(string):
         return quote.propertiesdecode(string)
 
     @classmethod
@@ -292,16 +294,15 @@ class Dialect:
         for delimiter in cls.delimiters:
             delimiter_dict[delimiter] = -1
         delimiters = delimiter_dict
-        # Find the position of each delimiter type
-        for delimiter, pos in delimiters.items():
-            start_pos = len(line) - len(line.lstrip())  # Skip initial whitespace
-            if cls.key_wrap_char != "" and line[start_pos] == cls.key_wrap_char:
-                # Skip the key if it is delimited by some char
+        # Figure out starting position
+        start_pos = len(line) - len(line.lstrip())  # Skip initial whitespace
+        if cls.key_wrap_char != "" and line[start_pos] == cls.key_wrap_char:
+            # Skip the key if it is delimited by some char
+            start_pos += 1
+            while line[start_pos] != cls.key_wrap_char or line[start_pos - 1] == "\\":
                 start_pos += 1
-                while (
-                    line[start_pos] != cls.key_wrap_char or line[start_pos - 1] == "\\"
-                ):
-                    start_pos += 1
+        # Find the position of each delimiter type
+        for delimiter in delimiters:
             pos = line.find(delimiter, start_pos)
             while pos != -1:
                 if delimiters[delimiter] == -1 and line[pos - 1] != "\\":
@@ -332,30 +333,30 @@ class Dialect:
                 return (" ", delimiters[" "])
         return (mindelimiter, minpos)
 
-    @classmethod
-    def key_strip(cls, key):
+    @staticmethod
+    def key_strip(key):
         """Strip unneeded characters from the key"""
         return _key_strip(key)
 
-    @classmethod
-    def value_strip(cls, value):
+    @staticmethod
+    def value_strip(value):
         """Strip unneeded characters from the value"""
         return value.lstrip()
 
-    @classmethod
-    def is_line_continuation(cls, line):
+    @staticmethod
+    def is_line_continuation(line):
         return is_line_continuation(line)
 
-    @classmethod
-    def strip_line_continuation(cls, value):
+    @staticmethod
+    def strip_line_continuation(value):
         return value[:-1]
 
-    @classmethod
-    def get_key_cldr_name(cls, key):
+    @staticmethod
+    def get_key_cldr_name(key):
         return (key, "other")
 
-    @classmethod
-    def get_cldr_names_order(cls):
+    @staticmethod
+    def get_cldr_names_order():
         return ["other"]
 
 
@@ -372,8 +373,8 @@ class DialectJavaUtf8(DialectJava):
     default_encoding = "utf-8"
     delimiters = ["=", ":", " "]
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         return quote.java_utf8_properties_encode(string or "")
 
 
@@ -383,8 +384,8 @@ class DialectJavaUtf16(DialectJava):
     default_encoding = "utf-16"
     delimiters = ["=", ":", " "]
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         return quote.java_utf8_properties_encode(string or "")
 
 
@@ -399,13 +400,14 @@ class DialectXWiki(DialectJava):
     name = "xwiki"
     default_encoding = "iso-8859-1"
     delimiters = ["=", ":", " "]
+    has_plurals = True
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         return quote.xwiki_properties_encode(string or "", encoding)
 
-    @classmethod
-    def decode(cls, string):
+    @staticmethod
+    def decode(string):
         return quote.xwiki_properties_decode(string)
 
 
@@ -420,8 +422,8 @@ class DialectMozilla(DialectJavaUtf8):
     name = "mozilla"
     delimiters = ["="]
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         """Encode the string"""
         string = quote.java_utf8_properties_encode(string or "")
         string = quote.mozillaescapemarginspaces(string or "")
@@ -435,11 +437,11 @@ class DialectGaia(DialectMozilla):
 
 
 @register_dialect
-class DialectGwt(DialectJava):
+class DialectGwt(DialectJavaUtf8):
     plural_regex = re.compile(r"([^\[\]]*)(?:\[(.*)\])?")
     name = "gwt"
-    default_encoding = "utf-8"
     delimiters = ["="]
+    has_plurals = True
 
     gwt_plural_categories = [
         ("", "other"),
@@ -450,22 +452,22 @@ class DialectGwt(DialectJava):
         ("many", "many"),
     ]
 
-    gwt2cldr = collections.OrderedDict(gwt_plural_categories)
-    cldr2gwt = collections.OrderedDict([(b, a) for a, b in gwt_plural_categories])
+    gwt2cldr = dict(gwt_plural_categories)
+    cldr2gwt = {b: a for a, b in gwt_plural_categories}
 
     @classmethod
     def get_key_cldr_name(cls, key):
-        match = cls.plural_regex.match(key)
-        key = match.group(1)
+        match = cls.plural_regex.fullmatch(key)
+        basekey = match.group(1)
         variant = match.group(2)
-        if not variant:
+        if variant is None:
             variant = ""
 
-        variant = cls.gwt2cldr.get(variant)
-        # Some sanity checks
-        if not variant:
-            raise Exception(f'Key "{key}" variant "{variant}" is invalid')
-        return (key, variant)
+        try:
+            variant = cls.gwt2cldr[variant]
+        except KeyError:
+            return (key, "other")
+        return (basekey, variant)
 
     @classmethod
     def get_cldr_names_order(cls):
@@ -482,7 +484,13 @@ class DialectGwt(DialectJava):
 
     @classmethod
     def encode(cls, string, encoding=None):
-        return quote.java_utf8_properties_encode(string or "")
+        result = super().encode(string, encoding)
+        return result.replace("'", "''")
+
+    @classmethod
+    def decode(cls, string):
+        result = super().decode(string)
+        return result.replace("''", "'")
 
 
 @register_dialect
@@ -491,8 +499,8 @@ class DialectSkype(Dialect):
     default_encoding = "utf-16"
     delimiters = ["="]
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         return quote.java_utf8_properties_encode(string or "")
 
 
@@ -508,8 +516,8 @@ class DialectStrings(Dialect):
     out_delimiter_wrappers = " "
     drop_comments = ["/* No comment provided by engineer. */"]
 
-    @classmethod
-    def key_strip(cls, key):
+    @staticmethod
+    def key_strip(key):
         """Strip unneeded characters from the key"""
         newkey = key.rstrip().rstrip('"')
         # If string now ends in \ we put back the char that was escaped
@@ -518,8 +526,8 @@ class DialectStrings(Dialect):
         ret = newkey.lstrip().lstrip('"')
         return ret.replace('\\"', '"')
 
-    @classmethod
-    def value_strip(cls, value):
+    @staticmethod
+    def value_strip(value):
         """Strip unneeded characters from the value"""
         newvalue = value.rstrip().rstrip(";").rstrip('"')
         # If string now ends in \ we put back the char that was escaped
@@ -528,19 +536,19 @@ class DialectStrings(Dialect):
         ret = newvalue.lstrip().lstrip('"')
         return ret.replace('\\"', '"')
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         return string.replace("\n", r"\n").replace("\t", r"\t")
 
-    @classmethod
-    def is_line_continuation(self, line):
+    @staticmethod
+    def is_line_continuation(line):
         l = line.rstrip()
         if l and l[-1] == ";":
             return False
         return True
 
-    @classmethod
-    def strip_line_continuation(cls, value):
+    @staticmethod
+    def strip_line_continuation(value):
         return value
 
 
@@ -564,22 +572,24 @@ class proppluralunit(base.TranslationUnit):
     def _get_language_mapping(lang):
         if lang:
             locale = lang.replace("_", "-").split("-")[0]
-            cldr_mapping = data.plural_tags.get(locale, data.plural_tags["en"])
-            if cldr_mapping:
-                return cldr_mapping
+            return data.plural_tags.get(locale, data.plural_tags["en"])
         return None
 
+    def _get_existing_mapping(self):
+        existing = self.units.keys()
+        return [key for key in data.cldr_plural_categories if key in existing]
+
     def _get_target_mapping(self):
         cldr_mapping = proppluralunit._get_language_mapping(self._store.targetlanguage)
         if cldr_mapping:
             return cldr_mapping
-        return self.units.keys()
+        return self._get_existing_mapping()
 
     def _get_source_mapping(self):
         cldr_mapping = proppluralunit._get_language_mapping(self._store.sourcelanguage)
         if cldr_mapping:
             return cldr_mapping
-        return self.units.keys()
+        return self._get_existing_mapping()
 
     def _get_units(self, mapping):
         ret = []
@@ -594,10 +604,11 @@ class proppluralunit(base.TranslationUnit):
             ret.append(self.units[proppluralunit.KEY])
         return ret
 
-    def _get_strings(self, strings, mapping):
+    @staticmethod
+    def _get_strings(strings, mapping):
         ret = []
         if len(strings) > 1:
-            for i, name in enumerate(mapping):
+            for i in range(len(mapping)):
                 if i < len(strings):
                     ret.append(strings[i])
                 else:
@@ -640,10 +651,7 @@ class proppluralunit(base.TranslationUnit):
         strings = self._get_strings(strings, mapping)
         units = self._get_units(mapping)
         if len(strings) != len(units):
-            raise Exception(
-                'Not same plural counts between "%s" and "%s"'
-                % (str(strings), str(units))
-            )
+            raise Exception(f'Not same plural counts between "{strings}" and "{units}"')
 
         for a, b in zip(strings, units):
             b.target = a
@@ -660,8 +668,7 @@ class proppluralunit(base.TranslationUnit):
         ll = [x.source for x in self._get_units(self._get_source_mapping())]
         if len(ll) > 1:
             return multistring(ll)
-        else:
-            return ll[0]
+        return ll[0]
 
     def setsource(self, text):
         mapping = None
@@ -679,10 +686,7 @@ class proppluralunit(base.TranslationUnit):
         strings = self._get_strings(strings, mapping)
         units = self._get_units(mapping)
         if len(strings) != len(units):
-            raise Exception(
-                'Not same plural counts between "%s" and "%s"'
-                % (str(strings), str(units))
-            )
+            raise Exception(f'Not same plural counts between "{strings}" and "{units}"')
 
         for a, b in zip(strings, units):
             b.source = a
@@ -759,10 +763,7 @@ class proppluralunit(base.TranslationUnit):
         return self.getoutput()
 
     def getoutput(self):
-        ret = ""
-        for x in self._get_ordered_units():
-            ret += x.getoutput()
-        return ret
+        return "".join(unit.getoutput() for unit in self._get_ordered_units())
 
     @property
     def encoding(self):
@@ -778,22 +779,20 @@ class DialectJoomla(Dialect):
     delimiters = ["="]
     out_delimiter_wrappers = ""
 
-    @classmethod
-    def value_strip(cls, value):
+    @staticmethod
+    def value_strip(value):
         """Strip unneeded characters from the value"""
-        newvalue = value.strip()
-        if not newvalue:
-            return newvalue
-        if newvalue[0] == '"' and newvalue[-1] == '"':
-            newvalue = newvalue[1:-1]
-        return newvalue.replace('"_QQ_"', '"')
+        return value.strip()
 
     @classmethod
     def decode(cls, string):
-        return cls.value_strip(string)
+        string = super().decode(string)
+        if len(string) > 2 and string[0] == '"' and string[-1] == '"':
+            string = string[1:-1]
+        return string.replace('"_QQ_"', '"')
 
-    @classmethod
-    def encode(cls, string, encoding=None):
+    @staticmethod
+    def encode(string, encoding=None):
         """Encode the string"""
         if not string:
             return string
@@ -838,18 +837,18 @@ class propunit(base.TranslationUnit):
     def missing(self, missing):
         self.explicitely_missing = missing
 
-    @classmethod
-    def get_missing_part(cls):
+    @staticmethod
+    def get_missing_part():
         """Return the string representing a missing translation."""
         return ""
 
-    @classmethod
-    def strip_missing_part(cls, line):
+    @staticmethod
+    def strip_missing_part(line):
         """Remove the missing prefix from the line."""
         return line
 
-    @classmethod
-    def represents_missing(cls, line):
+    @staticmethod
+    def represents_missing(line):
         """The line represents a missing translation"""
         return False
 
@@ -876,8 +875,7 @@ class propunit(base.TranslationUnit):
     def encoding(self):
         if self._store:
             return self._store.encoding
-        else:
-            return self.personality.default_encoding
+        return self.personality.default_encoding
 
     def __str__(self):
         """Convert to a string."""
@@ -888,41 +886,27 @@ class propunit(base.TranslationUnit):
         notes = self.getnotes()
         if self.isblank():
             return notes + "\n"
-        else:
-            if notes:
-                notes = notes + "\n"
-            self.value = self.personality.encode(self.source, self.encoding)
-            self.translation = self.personality.encode(self.target, self.encoding)
-            # encode key, if needed
-            key = self.name
-            kwc = self.personality.key_wrap_char
-            if kwc:
-                key = key.replace(kwc, "\\%s" % kwc)
-                key = f"{kwc}{key}{kwc}"
-            # encode value, if needed
-            value = self.translation or self.value
-            vwc = self.personality.value_wrap_char
-            if vwc:
-                value = value.replace(vwc, "\\%s" % vwc)
-                value = f"{vwc}{value}{vwc}"
-            wrappers = self.out_delimiter_wrappers
-            delimiter = f"{wrappers}{self.delimiter}{wrappers}"
-            ending = self.out_ending
-            missing_prefix = ""
-            if self.missing and self.output_missing:
-                missing_prefix = self.get_missing_part()
-            out_dict = {
-                "notes": notes,
-                "missing_prefix": missing_prefix,
-                "key": key,
-                "del": delimiter,
-                "value": value,
-                "ending": ending,
-            }
-            return (
-                "%(notes)s%(missing_prefix)s%(key)s%(del)s%(value)s%(ending)s\n"
-                % out_dict
-            )
+        if notes:
+            notes = notes + "\n"
+        # encode key, if needed
+        key = self.name
+        kwc = self.personality.key_wrap_char
+        if kwc:
+            key = key.replace(kwc, f"\\{kwc}")
+            key = f"{kwc}{key}{kwc}"
+        # encode value, if needed
+        value = self.translation or self.value
+        vwc = self.personality.value_wrap_char
+        if vwc:
+            value = value.replace(vwc, f"\\{vwc}")
+            value = f"{vwc}{value}{vwc}"
+        wrappers = self.out_delimiter_wrappers
+        delimiter = f"{wrappers}{self.delimiter}{wrappers}"
+        ending = self.out_ending
+        missing_prefix = ""
+        if self.output_missing and self.missing:
+            missing_prefix = self.get_missing_part()
+        return f"{notes}{missing_prefix}{key}{delimiter}{value}{ending}\n"
 
     def getlocations(self):
         return [self.name]
@@ -936,8 +920,7 @@ class propunit(base.TranslationUnit):
     def getnotes(self, origin=None):
         if origin in ["programmer", "developer", "source code", None]:
             return "\n".join(self.comments)
-        else:
-            return super().getnotes(origin)
+        return super().getnotes(origin)
 
     def removenotes(self, origin=None):
         self.comments = []
@@ -967,8 +950,8 @@ class xwikiunit(propunit):
         super().__init__(source, personality)
         self.output_missing = True
 
-    @classmethod
-    def get_missing_part(cls):
+    @staticmethod
+    def get_missing_part():
         """Return the string representing a missing translation."""
         return "### Missing: "
 
@@ -1102,7 +1085,8 @@ class propfile(base.TranslationStore):
         ):
             self.addunit(newunit)
 
-        self.fold()
+        if self.personality.has_plurals:
+            self.fold()
 
     def fold(self):
         old_units = self.units
@@ -1113,7 +1097,9 @@ class propfile(base.TranslationStore):
                 self.addunit(unit)
                 continue
             (key, variant) = self.personality.get_key_cldr_name(unit.name)
+            print(f"fold: {key!r} {variant!r} < {unit.name!r}")
             if key not in plurals or plurals[key].hasplural(variant):
+                print(f"generate {key!r}")
                 # Generate fake unit for each keys (MUST use None as source)
                 new_unit = proppluralunit(None, self.personality.name)
                 new_unit.name = key
@@ -1257,7 +1243,11 @@ class XWikiPageProperties(xwikifile):
         self.root = None
         super(xwikifile, self).__init__(*args, **kwargs)
 
-    def get_parser(self):
+    def is_source_file(self):
+        return self.getsourcelanguage() == self.gettargetlanguage()
+
+    @staticmethod
+    def get_parser():
         return etree.XMLParser(strip_cdata=False, resolve_entities=False)
 
     def extract_language(self):
@@ -1278,10 +1268,10 @@ class XWikiPageProperties(xwikifile):
             super().parse(content)
 
     def set_xwiki_xml_attributes(self, newroot):
-        for e in newroot.findall("object"):
-            newroot.remove(e)
-        for e in newroot.findall("attachment"):
-            newroot.remove(e)
+        for child in newroot.findall("object"):
+            newroot.remove(child)
+        for child in newroot.findall("attachment"):
+            newroot.remove(child)
         newroot.find("translation").text = "1"
         language_node = newroot.find("language")
 
@@ -1308,7 +1298,10 @@ class XWikiPageProperties(xwikifile):
         newroot.find("content").text = (
             "".join(unit.getoutput() for unit in self.units).strip() + "\n"
         )
-        self.set_xwiki_xml_attributes(newroot)
+        # We only modify the XML attributes if we are editing a translation file
+        # if we are editing the source file we should not modify it.
+        if not self.is_source_file():
+            self.set_xwiki_xml_attributes(newroot)
         self.write_xwiki_xml(newroot, out)
 
 
@@ -1335,7 +1328,8 @@ class XWikiFullPage(XWikiPageProperties):
             self.extract_language()
             super(XWikiPageProperties, self).parse(forparsing.encode(self.encoding))
 
-    def output_unit(self, unit):
+    @staticmethod
+    def output_unit(unit):
         value = unit.personality.encode(unit.source, unit.encoding)
         translation = unit.personality.encode(unit.target, unit.encoding)
         return translation or value
@@ -1352,5 +1346,8 @@ class XWikiFullPage(XWikiPageProperties):
             newroot.find("content").text = self.output_unit(unit_content).replace(
                 "\\n", "\n"
             )
-        self.set_xwiki_xml_attributes(newroot)
+        # We only modify the XML attributes if we are editing a translation file
+        # if we are editing the source file we should not modify it.
+        if not self.is_source_file():
+            self.set_xwiki_xml_attributes(newroot)
         self.write_xwiki_xml(newroot, out)
