@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2009 Zuza Software Foundation
 # Copyright 2013 F Wolff
@@ -25,13 +24,11 @@ files (pofile).
 import copy
 import logging
 import re
-import six
 import textwrap
-from itertools import chain
+import unicodedata
+from typing import List, Tuple
 
-from translate.lang import data
 from translate.misc import quote
-from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage import pocommon, poparser
 
@@ -44,8 +41,8 @@ lsep = "\n#: "
 
 # general functions for quoting / unquoting po strings
 
-po_unescape_map = {"\\r": "\r", "\\t": "\t", '\\"': '"', '\\n': '\n', '\\\\': '\\'}
-po_escape_map = dict([(value, key) for (key, value) in po_unescape_map.items()])
+po_unescape_map = {"\\r": "\r", "\\t": "\t", '\\"': '"', "\\n": "\n", "\\\\": "\\"}
+po_escape_map = {value: key for (key, value) in po_unescape_map.items()}
 
 
 def splitlines(text):
@@ -61,23 +58,23 @@ def splitlines(text):
     """
     # Strip UTF-8 BOM if present. This file would not be accepted
     # by gettext, but some editors might create it, so better handle it.
-    if text[:3] == b'\xEF\xBB\xBF':
+    if text[:3] == b"\xEF\xBB\xBF":
         text = text[3:]
     # Find first newline
-    newline = b'\n'
-    msgid_pos = max(0, text.find(b'msgid'))
+    newline = b"\n"
+    msgid_pos = max(0, text.find(b"\rmsgid ") + 1, text.find(b"\nmsgid ") + 1)
     for i, ch in enumerate(text[msgid_pos:]):
         # Iteration over bytes yields numbers in Python 3
-        if ch in ('\n', 10):
+        if ch == 10:
             break
-        if ch in ('\r', 13):
-            if text[msgid_pos + i + 1] in ('\n', 10):
-                newline = b'\r\n'
+        if ch == 13:
+            if text[msgid_pos + i + 1] == 10:
+                newline = b"\r\n"
             else:
-                newline = b'\r'
+                newline = b"\r"
             break
 
-    return [x + newline for x in text.split(newline)]
+    return [x + newline for x in text.split(newline)], newline.decode()
 
 
 def escapeforpo(line):
@@ -93,7 +90,7 @@ def escapeforpo(line):
     last_location = 0
     for location in special_locations:
         escaped_line.append(line[last_location:location])
-        escaped_line.append(po_escape_map[line[location:location+1]])
+        escaped_line.append(po_escape_map[line[location : location + 1]])
         last_location = location + 1
     escaped_line.append(line[last_location:])
     return "".join(escaped_line)
@@ -103,64 +100,170 @@ def unescapehandler(escape):
     return po_unescape_map.get(escape, escape)
 
 
-wrapper = textwrap.TextWrapper(
-    width=77, replace_whitespace=False, expand_tabs=False,
-    drop_whitespace=False)
-wrapper.wordsep_re = re.compile(
-    r'(\s+|'                                  # any whitespace
-    r'[a-z0-9A-Z_-]+/|'                       # nicely split long URLs
-    r'\w*\\.|'                                # any escape should not be split
-    r'[\w\!\'\&\.\,\?]+\s+|'                  # space should go with a word
-    r'[^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|'   # hyphenated words
-    r'(?<=[\w\!\"\'\&\.\,\?])-{2,}(?=\w))')   # em-dash
-wrapper.wordsep_re_uni = re.compile(wrapper.wordsep_re.pattern, re.UNICODE)
+WIDE_CHARS = {"F", "W"}
+
+
+def cjklen(text: str) -> int:
+    """
+    Return the real width of an unicode text, the len of any other type.
+
+    Fullwidth and Wide CJK chars are double-width.
+    """
+    return sum(
+        2 if unicodedata.east_asian_width(char) in WIDE_CHARS else 1 for char in text
+    )
+
+
+def cjkslices(text: str, index: int) -> Tuple[str, str]:
+    """Return the two slices of a text cut to the index."""
+    if cjklen(text) <= index:
+        return text, ""
+    length = 0
+    i = 0
+    for i in range(len(text)):
+        length += cjklen(text[i])
+        if length > index:
+            break
+    return text[:i], text[i:]
+
+
+class PoWrapper(textwrap.TextWrapper):
+    """
+    Customized TextWrapper
+
+    - custom word separator regexp
+    - full width chars accounting, based on https://bugs.python.org/issue24665
+    - dropped support for unused features (for example max_lines or drop_whitespace)
+    """
+
+    wordsep_re = re.compile(
+        r"""
+            (
+            \s+|                                  # any whitespace
+            [a-z0-9A-Z_-]+/|                      # nicely split long URLs
+            \w*\\.\w*|                            # any escape should not be split
+            n(?=%)|                               # wrap insidide plural equation
+            \.(?=\w)|                             # full stop inside word
+            [\w\!\'\&\.\,\?=<>%]+\s+|             # space should go with a word
+            [^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|  # hyphenated words
+            (?<=[\w\!\"\'\&\.\,\?])-{2,}(?=\w)    # em-dash
+            )
+        """,
+        re.VERBOSE,
+    )
+
+    def __init__(self, width=77):
+        super().__init__(
+            width=width,
+            replace_whitespace=False,
+            expand_tabs=False,
+            drop_whitespace=False,
+            break_long_words=True,
+        )
+
+    def _handle_long_word(
+        self, reversed_chunks: List[str], cur_line: List[str], cur_len: int, width: int
+    ):
+        """
+        Handle a chunk of text (most likely a word, not whitespace) that
+        is too long to fit in any line.
+        """
+        # Figure out when indent is larger than the specified width, and make
+        # sure at least one character is stripped off on every pass
+        if width < 1:
+            space_left = 1
+        else:
+            space_left = width - cur_len
+
+        # We're allowed to break long words, then do so: put as much
+        # of the next chunk onto the current line as will fit.
+        chunk_start, chunk_end = cjkslices(reversed_chunks[-1], space_left)
+        cur_line.append(chunk_start)
+        reversed_chunks[-1] = chunk_end
+
+    def _wrap_chunks(self, chunks: List[str]) -> List[str]:
+        lines = []
+        if self.width <= 1:
+            raise ValueError("invalid width %r (must be > 1)" % self.width)
+
+        # Arrange in reverse order so items can be efficiently popped
+        # from a stack of chucks.
+        chunks.reverse()
+
+        while chunks:
+
+            # Start the list of chunks that will make up the current line.
+            # cur_len is just the length of all the chunks in cur_line.
+            cur_line = []
+            cur_len = 0
+
+            # Figure out which static string will prefix this line.
+            if lines:
+                indent = self.subsequent_indent
+            else:
+                indent = self.initial_indent
+
+            # Maximum width for this line.
+            width = self.width - len(indent)
+
+            while chunks:
+                l = cjklen(chunks[-1])
+
+                # Can at least squeeze this chunk onto the current line.
+                if cur_len + l <= width:
+                    cur_line.append(chunks.pop())
+                    cur_len += l
+
+                # Nope, this line is full.
+                else:
+                    break
+
+            # The current line is full, and the next chunk is too big to
+            # fit on *any* line (not just this one).
+            if chunks and cjklen(chunks[-1]) > width:
+                self._handle_long_word(chunks, cur_line, cur_len, width)
+
+            if cur_line:
+                # Convert current line back to a string and store it in
+                # list of all lines (return value).
+                lines.append(indent + "".join(cur_line))
+        return lines
 
 
 def quoteforpo(text, wrapper_obj=None):
-    """Quotes the given text for a PO file, returning quoted and escaped lines
-    """
+    """Quotes the given text for a PO file, returning quoted and escaped lines"""
     if text is None:
         return []
     if wrapper_obj is None:
-        wrapper_obj = wrapper
+        wrapper_obj = PoWrapper()
     text = escapeforpo(text)
     if wrapper_obj.width == -1:
-        return [u'"%s"' % text]
-    lines = text.split(u"\\n")
+        return ['"%s"' % text]
+    lines = text.split("\\n")
     for i, l in enumerate(lines[:-1]):
-        lines[i] = l + u"\\n"
+        lines[i] = l + "\\n"
 
     polines = []
     len_lines = len(lines)
-    if len_lines > 2 or (len_lines == 2 and lines[1]) or len(lines[0]) > wrapper_obj.width - 6:
-        polines.append(u'""')
+    if (
+        len_lines > 2
+        or (len_lines == 2 and lines[1])
+        or len(lines[0]) > wrapper_obj.width - 6
+    ):
+        polines.append('""')
     for line in lines:
         lns = wrapper_obj.wrap(line)
         for ln in lns:
-            polines.append(u'"%s"' % ln)
+            polines.append('"%s"' % ln)
     return polines
 
 
-@deprecated("Use pypo.unescape() instead")
-def extractpoline(line):
-    """Remove quote and unescape line from po file.
-
-    :param line: a quoted line from a po file (msgid or msgstr)
-
-    .. deprecated:: 1.10
-       Replaced by :func:`unescape`. :func:`extractpoline` is kept to allow
-       tests of correctness, and in case of external users.
-    """
-    extracted = quote.extractwithoutquotes(line, '"', '"', '\\', includeescapes=unescapehandler)[0]
-    return extracted
-
-
 def unescape(line):
     """Unescape the given line.
 
     Quotes on either side should already have been removed.
     """
-    escape_places = quote.find_all(line, u"\\")
+    escape_places = quote.find_all(line, "\\")
     if not escape_places:
         return line
 
@@ -181,15 +284,15 @@ def unescape(line):
         # everything leading up to the escape
         extracted.append(line[lastpos:pos])
         # the escaped sequence (consuming 2 characters)
-        extracted.append(unescapehandler(line[pos:pos+2]))
-        lastpos = pos+2
+        extracted.append(unescapehandler(line[pos : pos + 2]))
+        lastpos = pos + 2
 
     extracted.append(line[lastpos:])
-    return u"".join(extracted)
+    return "".join(extracted)
 
 
 def unquotefrompo(postr):
-    return u"".join([unescape(line[1:-1]) for line in postr])
+    return "".join(unescape(line[1:-1]) for line in postr)
 
 
 def is_null(lst):
@@ -200,11 +303,10 @@ def extractstr(string):
     left = string.find('"')
     right = string.rfind('"')
     if right > -1:
-        return string[left:right+1]
+        return string[left : right + 1]
     return string[left:] + '"'
 
 
-@six.python_2_unicode_compatible
 class pounit(pocommon.pounit):
     # othercomments = []      #   # this is another comment
     # automaticcomments = []  #   #. comment extracted from the source code
@@ -220,7 +322,7 @@ class pounit(pocommon.pounit):
 
     # Our homegrown way to indicate what must be copied in a shallow
     # fashion
-    __shallow__ = ['_store', 'wrapper']
+    __shallow__ = ["_store", "wrapper"]
 
     def __init__(self, source=None, wrapper=None, **kwargs):
         self.wrapper = wrapper
@@ -234,7 +336,13 @@ class pounit(pocommon.pounit):
         self.msgid_pluralcomments = []
         self.msgid_plural = []
         self.msgstr = []
-        pocommon.pounit.__init__(self, source)
+        super().__init__(source)
+
+    @property
+    def newline(self):
+        if self._store is not None:
+            return self._store.newline
+        return "\n"
 
     def _initallcomments(self, blankall=False):
         """Initialises allcomments"""
@@ -246,12 +354,13 @@ class pounit(pocommon.pounit):
             self.msgidcomments = []
 
     def _get_all_comments(self):
-        return [self.othercomments,
-                self.automaticcomments,
-                self.sourcecomments,
-                self.typecomments,
-                self.msgidcomments,
-                ]
+        return [
+            self.othercomments,
+            self.automaticcomments,
+            self.sourcecomments,
+            self.typecomments,
+            self.msgidcomments,
+        ]
 
     allcomments = property(_get_all_comments)
 
@@ -268,9 +377,6 @@ class pounit(pocommon.pounit):
     def _set_source_vars(self, source):
         msgid = None
         msgid_plural = None
-        if isinstance(source, bytes):
-            # Guessing utf-8, non-ascii encoded content should not reach this point
-            source = source.decode('utf-8')
         if isinstance(source, multistring):
             source = source.strings
         if isinstance(source, list):
@@ -298,11 +404,6 @@ class pounit(pocommon.pounit):
         self._rich_source = None
         self.msgid, self.msgid_plural = self._set_source_vars(source)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     def _get_prev_source(self):
         """Returns the unescaped msgid"""
         return self._get_source_vars(self.prev_msgid, self.prev_msgid_plural)
@@ -313,6 +414,7 @@ class pounit(pocommon.pounit):
         :param source: an unescaped source string.
         """
         self.prev_msgid, self.prev_msgid_plural = self._set_source_vars(source)
+
     prev_source = property(_get_prev_source, _set_prev_source)
 
     @property
@@ -326,34 +428,31 @@ class pounit(pocommon.pounit):
     def target(self, target):
         """Sets the msgstr to the given (unescaped) value"""
         self._rich_target = None
-        if isinstance(target, bytes):
-            # Guessing utf-8, non-ascii encoded content should not reach this point
-            target = target.decode('utf-8')
         if self.hasplural():
             if isinstance(target, multistring):
                 target = target.strings
-            elif isinstance(target, six.string_types):
+            elif isinstance(target, str):
                 target = [target]
         elif isinstance(target, (dict, list)):
             if len(target) == 1:
                 target = target[0]
             else:
-                raise ValueError("po msgid element has no plural but msgstr has %d elements (%s)" % (len(target), target))
+                raise ValueError(
+                    "po msgid element has no plural but msgstr has %d elements (%s)"
+                    % (len(target), target)
+                )
         templates = self.msgstr
         if isinstance(templates, list):
             templates = {0: templates}
         if isinstance(target, list):
-            self.msgstr = dict([(i, self.quote(target[i])) for i in range(len(target))])
+            self.msgstr = {i: self.quote(target[i]) for i in range(len(target))}
         elif isinstance(target, dict):
-            self.msgstr = dict([(i, self.quote(targetstring)) for i, targetstring in six.iteritems(target)])
+            self.msgstr = {
+                i: self.quote(targetstring) for i, targetstring in target.items()
+            }
         else:
             self.msgstr = self.quote(target)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
-
     def getalttrans(self):
         """Return a list of alternate units.
 
@@ -367,7 +466,7 @@ class pounit(pocommon.pounit):
             # Already released versions of Virtaal (0.6.x) only supported XLIFF
             # alternatives, and expect .xmlelement.get().
             # This can be removed soon:
-            unit.xmlelement = dict()
+            unit.xmlelement = {}
             return [unit]
         return []
 
@@ -377,12 +476,20 @@ class pounit(pocommon.pounit):
         :param origin: programmer, developer, source code, translator or None
         """
         if origin is None:
-            comments = u"".join([comment[2:] or "\n" for comment in self.othercomments])
-            comments += u"".join([comment[3:] or "\n" for comment in self.automaticcomments])
+            comments = "".join(
+                comment[2:] or self.newline for comment in self.othercomments
+            )
+            comments += "".join(
+                comment[3:] or self.newline for comment in self.automaticcomments
+            )
         elif origin == "translator":
-            comments = u"".join([comment[2:] or "\n" for comment in self.othercomments])
+            comments = "".join(
+                comment[2:] or self.newline for comment in self.othercomments
+            )
         elif origin in ["programmer", "developer", "source code"]:
-            comments = u"".join([comment[3:] or "\n" for comment in self.automaticcomments])
+            comments = "".join(
+                comment[3:] or self.newline for comment in self.automaticcomments
+            )
         else:
             raise ValueError("Comment type not valid")
         # Let's drop the last newline
@@ -396,7 +503,6 @@ class pounit(pocommon.pounit):
         # ignore empty strings and strings without non-space characters
         if not (text and text.strip()):
             return
-        text = data.forceunicode(text)
         commentlist = self.othercomments
         linestart = "#"
         autocomments = False
@@ -405,8 +511,8 @@ class pounit(pocommon.pounit):
             commentlist = self.automaticcomments
             linestart = "#."
         newcomments = [
-            "".join((linestart, " " if line else "", line, "\n"))
-            for line in text.split("\n")
+            "".join((linestart, " " if line else "", line, self.newline))
+            for line in text.split(self.newline)
         ]
         if position == "append":
             newcomments = commentlist + newcomments
@@ -429,7 +535,7 @@ class pounit(pocommon.pounit):
         # self.__shallow__
         shallow = set(self.__shallow__)
         # Make deep copies of all members which are not in shallow
-        for key, value in six.iteritems(self.__dict__):
+        for key, value in self.__dict__.items():
             if key not in shallow:
                 setattr(new_unit, key, copy.deepcopy(value))
         # Make shallow copies of all members which are in shallow
@@ -446,12 +552,16 @@ class pounit(pocommon.pounit):
 
     def _msgidlen(self):
         if self.hasplural():
-            return len(unquotefrompo(self.msgid)) + len(unquotefrompo(self.msgid_plural))
+            return len(unquotefrompo(self.msgid)) + len(
+                unquotefrompo(self.msgid_plural)
+            )
         return len(unquotefrompo(self.msgid))
 
     def _msgstrlen(self):
         if isinstance(self.msgstr, dict):
-            combinedstr = "\n".join(filter(None, [unquotefrompo(msgstr) for msgstr in six.itervalues(self.msgstr)]))
+            combinedstr = self.newline.join(
+                filter(None, [unquotefrompo(msgstr) for msgstr in self.msgstr.values()])
+            )
             return len(combinedstr)
         return len(unquotefrompo(self.msgstr))
 
@@ -463,16 +573,7 @@ class pounit(pocommon.pounit):
         """
 
         def mergelists(list1, list2, split=False):
-            # Decode where necessary (either all bytestrings or all unicode)
-            if any(isinstance(item, six.text_type) for item in chain(list1, list2)):
-                for position, item in enumerate(list1):
-                    if isinstance(item, bytes):
-                        list1[position] = item.decode("utf-8")
-                for position, item in enumerate(list2):
-                    if isinstance(item, bytes):
-                        list2[position] = item.decode("utf-8")
-
-            #Determine the newline style of list1
+            # Determine the newline style of list1
             lineend = ""
             if list1 and list1[0]:
                 for candidate in ["\n", "\r", "\n\r"]:
@@ -483,7 +584,7 @@ class pounit(pocommon.pounit):
             else:
                 lineend = "\n"
 
-            #Split if directed to do so:
+            # Split if directed to do so:
             if split:
                 splitlist1 = []
                 splitlist2 = []
@@ -494,9 +595,15 @@ class pounit(pocommon.pounit):
                 for item in list2:
                     splitlist2.extend(item.split()[1:])
                     prefix = item.split()[0]
-                list1.extend(["%s %s%s" % (prefix, item, lineend) for item in splitlist2 if item not in splitlist1])
+                list1.extend(
+                    [
+                        f"{prefix} {item}{lineend}"
+                        for item in splitlist2
+                        if item not in splitlist1
+                    ]
+                )
             else:
-                #Normal merge, but conform to list1 newline style
+                # Normal merge, but conform to list1 newline style
                 if list1 != list2:
                     for item in list2:
                         if lineend:
@@ -504,8 +611,9 @@ class pounit(pocommon.pounit):
                         # avoid duplicate comment lines (this might cause some problems)
                         if item not in list1 or len(item) < 5:
                             list1.append(item)
+
         if not isinstance(otherpo, pounit):
-            super(pounit, self).merge(otherpo, overwrite, comments)
+            super().merge(otherpo, overwrite, comments)
             return
         if comments:
             mergelists(self.othercomments, otherpo.othercomments)
@@ -520,9 +628,14 @@ class pounit(pocommon.pounit):
         if not self.istranslated() or overwrite:
             # Remove kde-style comments from the translation (if any).
             if self._extract_msgidcomments(otherpo.target):
-                otherpo.target = otherpo.target.replace('_: ' + otherpo._extract_msgidcomments() + '\n', '')
+                otherpo.target = otherpo.target.replace(
+                    "_: " + otherpo._extract_msgidcomments() + self.newline, ""
+                )
             self.target = otherpo.target
-            if self.source != otherpo.source or self.getcontext() != otherpo.getcontext():
+            if (
+                self.source != otherpo.source
+                or self.getcontext() != otherpo.getcontext()
+            ):
                 self.markfuzzy()
             else:
                 self.markfuzzy(otherpo.isfuzzy())
@@ -534,17 +647,23 @@ class pounit(pocommon.pounit):
                 self.markfuzzy()
 
     def isheader(self):
-        #return (self._msgidlen() == 0) and (self._msgstrlen() > 0) and (len(self.msgidcomments) == 0)
-        #rewritten here for performance:
-        return (is_null(self.msgid)
-                and not is_null(self.msgstr)
-                and self.msgidcomments == []
-                and is_null(self.msgctxt))
+        # return (self._msgidlen() == 0) and (self._msgstrlen() > 0) and (len(self.msgidcomments) == 0)
+        # rewritten here for performance:
+        return (
+            is_null(self.msgid)
+            and not is_null(self.msgstr)
+            and self.msgidcomments == []
+            and is_null(self.msgctxt)
+        )
 
     def isblank(self):
         if self.isheader() or self.msgidcomments:
             return False
-        if (self._msgidlen() == 0) and (self._msgstrlen() == 0) and (is_null(self.msgctxt)):
+        if (
+            (self._msgidlen() == 0)
+            and (self._msgstrlen() == 0)
+            and (is_null(self.msgctxt))
+        ):
             return True
         return False
         # TODO: remove:
@@ -555,7 +674,7 @@ class pounit(pocommon.pounit):
         for tc in self.typecomments:
             for flag in tc.split(","):
                 value = flag.strip()
-                if not value or value == '#':
+                if not value or value == "#":
                     continue
                 yield value
 
@@ -590,12 +709,13 @@ class pounit(pocommon.pounit):
                 typecomments.remove(typecomment)
             if typecomments:
                 typecomments.sort()
-                self.typecomments = ["#, %s\n" % ", ".join(typecomments)]
+                comments_str = ", ".join(typecomments)
+                self.typecomments = [f"#, {comments_str}{self.newline}"]
             else:
                 self.typecomments = []
 
     def isfuzzy(self):
-        return self.hastypecomment('fuzzy')
+        return self.hastypecomment("fuzzy")
 
     def markfuzzy(self, present=True):
         if present:
@@ -613,34 +733,36 @@ class pounit(pocommon.pounit):
         if self.obsolete:
             self.makeobsolete()
         else:
-            self.markfuzzy(self.hastypecomment('fuzzy'))
+            self.markfuzzy(self.hastypecomment("fuzzy"))
 
     def isobsolete(self):
         return self.obsolete
 
     def makeobsolete(self):
         """Makes this unit obsolete"""
-        super(pounit, self).makeobsolete()
+        super().makeobsolete()
         self.obsolete = True
         self.sourcecomments = []
         self.automaticcomments = []
 
     def resurrect(self):
         """Makes an obsolete unit normal"""
-        super(pounit, self).resurrect()
+        super().resurrect()
         self.obsolete = False
 
     def hasplural(self):
         """returns whether this pounit contains plural strings..."""
         return len(self.msgid_plural) > 0
 
-    def parse(self, src):
-        return poparser.parse_unit(poparser.ParseState(splitlines(src), pounit), self)
-
     def _getmsgpartstr(self, partname, partlines, partcomments=""):
         if isinstance(partlines, dict):
             partkeys = sorted(partlines.keys())
-            return "".join([self._getmsgpartstr("%s[%d]" % (partname, partkey), partlines[partkey], partcomments) for partkey in partkeys])
+            return "".join(
+                self._getmsgpartstr(
+                    "%s[%d]" % (partname, partkey), partlines[partkey], partcomments
+                )
+                for partkey in partkeys
+            )
         partstr = [partname, " "]
         partstartline = 0
         if partlines and not partcomments:
@@ -649,7 +771,7 @@ class pounit(pocommon.pounit):
         elif partcomments:
             if partlines and not unquotefrompo(partlines[:1]):
                 # if there is a blank leader line, it must come before the comment
-                partstr.extend((partlines[0], '\n'))
+                partstr.extend((partlines[0], self.newline))
                 # but if the whole string is blank, leave it in
                 if len(partlines) > 1:
                     partstartline += 1
@@ -662,20 +784,20 @@ class pounit(pocommon.pounit):
                 for comment in partcomments:
                     comment = unquotefrompo([comment])
                     if comment.startswith("_:"):
-                        comment = comment[len("_:"):]
+                        comment = comment[len("_:") :]
                     if comment.endswith("\\n"):
-                        comment = comment[:-len("\\n")]
-                    #Before we used to strip. Necessary in some cases?
+                        comment = comment[: -len("\\n")]
+                    # Before we used to strip. Necessary in some cases?
                     combinedcomment.append(comment)
                 partcomments = self.quote("_:%s" % "".join(combinedcomment))
                 # Strip heading empty line for multiline string, it was already added above
                 if partcomments[0] == '""':
                     partcomments = partcomments[1:]
             # comments first, no blank leader line needed
-            partstr.append(quote.rstripeol("\n".join(partcomments)))
+            partstr.append(quote.rstripeol(self.newline.join(partcomments)))
         else:
             partstr.append('""')
-        partstr.append('\n')
+        partstr.append(self.newline)
         # add the rest
         previous = None
         for partline in partlines[partstartline:]:
@@ -683,7 +805,7 @@ class pounit(pocommon.pounit):
             if previous == '""' and partline == '""':
                 continue
             previous = partline
-            partstr.extend((partline, '\n'))
+            partstr.extend((partline, self.newline))
         return "".join(partstr)
 
     def __str__(self):
@@ -695,13 +817,13 @@ class pounit(pocommon.pounit):
 
         def add_prev_msgid_lines(lines, prefix, header, var):
             if var:
-                lines.append("%s %s %s\n" % (prefix, header, var[0]))
-                lines.extend("%s %s\n" % (prefix, line) for line in var[1:])
+                lines.append(f"{prefix} {header} {var[0]}\n")
+                lines.extend(f"{prefix} {line}\n" for line in var[1:])
 
         def add_prev_msgid_info(lines, prefix):
-            add_prev_msgid_lines(lines, prefix, 'msgctxt', self.prev_msgctxt)
-            add_prev_msgid_lines(lines, prefix, 'msgid', self.prev_msgid)
-            add_prev_msgid_lines(lines, prefix, 'msgid_plural', self.prev_msgid_plural)
+            add_prev_msgid_lines(lines, prefix, "msgctxt", self.prev_msgctxt)
+            add_prev_msgid_lines(lines, prefix, "msgid", self.prev_msgid)
+            add_prev_msgid_lines(lines, prefix, "msgid_plural", self.prev_msgid_plural)
 
         lines = []
         lines.extend(self.othercomments)
@@ -711,33 +833,43 @@ class pounit(pocommon.pounit):
             add_prev_msgid_info(obsoletelines, prefix="#~|")
             if self.msgctxt:
                 obsoletelines.append(self._getmsgpartstr("#~ msgctxt", self.msgctxt))
-            obsoletelines.append(self._getmsgpartstr("#~ msgid", self.msgid, self.msgidcomments))
+            obsoletelines.append(
+                self._getmsgpartstr("#~ msgid", self.msgid, self.msgidcomments)
+            )
             if self.msgid_plural or self.msgid_pluralcomments:
-                obsoletelines.append(self._getmsgpartstr("#~ msgid_plural", self.msgid_plural, self.msgid_pluralcomments))
+                obsoletelines.append(
+                    self._getmsgpartstr(
+                        "#~ msgid_plural", self.msgid_plural, self.msgid_pluralcomments
+                    )
+                )
             obsoletelines.append(self._getmsgpartstr("#~ msgstr", self.msgstr))
             for index, obsoleteline in enumerate(obsoletelines):
                 # We need to account for a multiline msgid or msgstr here
                 obsoletelines[index] = obsoleteline.replace('\n"', '\n#~ "')
             lines.extend(obsoletelines)
-            return u"".join(lines)
+            return "".join(lines)
         # if there's no msgid don't do msgid and string, unless we're the
         # header this will also discard any comments other than plain
         # othercomments...
-        if is_null(self.msgid):
-            if not (self.isheader() or self.getcontext() or self.sourcecomments):
-                return u"".join(lines)
+        if is_null(self.msgid) and not (
+            self.isheader() or self.getcontext() or self.sourcecomments
+        ):
+            return "".join(lines)
         lines.extend(self.automaticcomments)
         lines.extend(self.sourcecomments)
         lines.extend(self.typecomments)
         add_prev_msgid_info(lines, prefix="#|")
         if self.msgctxt:
-            lines.append(self._getmsgpartstr(u"msgctxt", self.msgctxt))
-        lines.append(self._getmsgpartstr(u"msgid", self.msgid, self.msgidcomments))
+            lines.append(self._getmsgpartstr("msgctxt", self.msgctxt))
+        lines.append(self._getmsgpartstr("msgid", self.msgid, self.msgidcomments))
         if self.msgid_plural or self.msgid_pluralcomments:
-            lines.append(self._getmsgpartstr(u"msgid_plural", self.msgid_plural, self.msgid_pluralcomments))
-        lines.append(self._getmsgpartstr(u"msgstr", self.msgstr))
-        postr = u"".join(lines)
-        return postr
+            lines.append(
+                self._getmsgpartstr(
+                    "msgid_plural", self.msgid_plural, self.msgid_pluralcomments
+                )
+            )
+        lines.append(self._getmsgpartstr("msgstr", self.msgstr))
+        return "".join(lines)
 
     def getlocations(self):
         """Get a list of locations from sourcecomments in the PO unit
@@ -760,9 +892,8 @@ class pounit(pocommon.pounit):
         :type location: String
 
         """
-        location = data.forceunicode(location)
         location = pocommon.quote_plus(location)
-        self.sourcecomments.append("#: %s\n" % location)
+        self.sourcecomments.append(f"#: {location}{self.newline}")
 
     def _extract_msgidcomments(self, text=None):
         """Extract KDE style msgid comments from the unit.
@@ -774,7 +905,7 @@ class pounit(pocommon.pounit):
 
         if not text:
             text = unquotefrompo(self.msgidcomments)
-        return text.split('\n')[0].replace('_: ', '', 1)
+        return text.split(self.newline)[0].replace("_: ", "", 1)
 
     def setmsgidcomment(self, msgidcomment):
         if msgidcomment:
@@ -789,7 +920,6 @@ class pounit(pocommon.pounit):
         return unquotefrompo(self.msgctxt) + self._extract_msgidcomments()
 
     def setcontext(self, context):
-        context = data.forceunicode(context)
         self.msgctxt = self.quote(context)
 
     def getid(self):
@@ -799,12 +929,12 @@ class pounit(pocommon.pounit):
         # the msgid. For generation of .mo files, we might want to use this
         # code to generate the entry for the hash table, but for now, it is
         # commented out for conformance to gettext.
-#        id = '\0'.join(self.source.strings)
+        #        id = '\0'.join(self.source.strings)
         id = self.source
         if self.msgidcomments:
-            id = u"_: %s\n%s" % (context, id)
+            id = f"_: {context}\n{id}"
         elif context:
-            id = u"%s\04%s" % (context, id)
+            id = f"{context}\04{id}"
         return id
 
 
@@ -814,26 +944,28 @@ class pofile(pocommon.pofile):
     UnitClass = pounit
 
     def __init__(self, inputfile=None, width=None, **kwargs):
-        self.wrapper = copy.copy(wrapper)
+        wrapargs = {}
         if width is not None:
-            self.wrapper.width = width
-        super(pofile, self).__init__(inputfile, **kwargs)
+            wrapargs = {"width": width}
+        self.wrapper = PoWrapper(**wrapargs)
+        self.newline = "\n"
+        super().__init__(inputfile, **kwargs)
 
     def create_unit(self):
         return self.UnitClass(wrapper=self.wrapper)
 
     def parse(self, input):
         """Parses the given file or file source string."""
-        if hasattr(input, 'name'):
+        if hasattr(input, "name"):
             self.filename = input.name
-        elif not getattr(self, 'filename', ''):
-            self.filename = ''
+        elif not getattr(self, "filename", ""):
+            self.filename = ""
         if not isinstance(input, bytes):
             input = input.read()
-        input = iter(splitlines(input))
+        lines, self.newline = splitlines(input)
         # clear units to get rid of automatically generated headers before parsing
         self.units = []
-        poparser.parse_units(poparser.ParseState(input, self.create_unit), self)
+        poparser.parse_units(poparser.ParseState(iter(lines), self.create_unit), self)
 
     def removeduplicates(self, duplicatestyle="merge"):
         """Make sure each msgid is unique ; merge comments etc from
@@ -850,6 +982,7 @@ class pofile(pocommon.pofile):
         def addcomment(thepo):
             thepo.msgidcomments.append('"_: %s\\n"' % " ".join(thepo.getlocations()))
             markedpos.append(thepo)
+
         for thepo in self.units:
             id = thepo.getid()
             if thepo.isheader() and not thepo.getlocations():
@@ -866,22 +999,29 @@ class pofile(pocommon.pofile):
                     origpo = id_dict[id]
                     if origpo not in markedpos and id:
                         # if it doesn't have an id, we already added msgctxt
-                        origpo.msgctxt.append('"%s"' % escapeforpo(" ".join(origpo.getlocations())))
+                        origpo.msgctxt.append(
+                            '"%s"' % escapeforpo(" ".join(origpo.getlocations()))
+                        )
                         markedpos.append(thepo)
-                    thepo.msgctxt.append('"%s"' % escapeforpo(" ".join(thepo.getlocations())))
+                    thepo.msgctxt.append(
+                        '"%s"' % escapeforpo(" ".join(thepo.getlocations()))
+                    )
                     if not thepo.msgctxt == id_dict[id].msgctxt:
                         uniqueunits.append(thepo)
                     else:
                         logger.warning(
                             "Duplicate unit found with msgctx of '%s' and source '%s'",
                             thepo.msgctxt,
-                            thepo.source)
+                            thepo.source,
+                        )
             else:
                 if not id:
                     if duplicatestyle == "merge":
                         addcomment(thepo)
                     else:
-                        thepo.msgctxt.append('"%s"' % escapeforpo(" ".join(thepo.getlocations())))
+                        thepo.msgctxt.append(
+                            '"%s"' % escapeforpo(" ".join(thepo.getlocations()))
+                        )
                 id_dict[id] = thepo
                 uniqueunits.append(thepo)
         self.units = uniqueunits
@@ -892,40 +1032,18 @@ class pofile(pocommon.pofile):
         try:
             for unit in self.units:
                 if not at_start:
-                    out.write(b'\n')
+                    out.write(self.newline.encode())
                 else:
                     at_start = False
                 out.write(unit._getoutput().encode(self.encoding))
-        except UnicodeEncodeError as e:
-            if self.encoding == 'utf-8':
+        except UnicodeEncodeError:
+            if self.encoding == "utf-8":
                 raise
             self.updateheader(add=True, Content_Type="text/plain; charset=UTF-8")
             self.encoding = "utf-8"
             out.seek(0)
             self.serialize(out)
 
-    def encode(self, lines):
-        """encode any unicode strings in lines in self.encoding"""
-        newlines = []
-        for line in lines:
-            if isinstance(line, six.text_type):
-                line = line.encode(self.encoding)
-            newlines.append(line)
-        return newlines
-
-    def decode(self, lines):
-        """decode any non-unicode strings in lines with self.encoding"""
-        newlines = []
-        for line in lines:
-            if isinstance(line, bytes):
-                try:
-                    line = line.decode(self.encoding)
-                except UnicodeDecodeError as e:
-                    raise UnicodeDecodeError("Error decoding line with encoding %r: %s. Line is %r" %
-                                             (self.encoding, e, line))
-            newlines.append(line)
-        return newlines
-
     def unit_iter(self):
         for unit in self.units:
             if not (unit.isheader() or unit.isobsolete()):
@@ -933,4 +1051,4 @@ class pofile(pocommon.pofile):
 
     def addunit(self, unit):
         unit.wrapper = self.wrapper
-        super(pofile, self).addunit(unit)
+        super().addunit(unit)
