@@ -189,7 +189,8 @@ class TestDTDUnit(test_monolingual.TestMonolingualUnit):
 class TestDTD(test_monolingual.TestMonolingualStore):
     StoreClass = dtd.dtdfile
 
-    def dtdparse(self, dtdsource):
+    @staticmethod
+    def dtdparse(dtdsource):
         """helper that parses dtd source without requiring files"""
         if not isinstance(dtdsource, bytes):
             dtdsource = dtdsource.encode("utf-8")
@@ -363,7 +364,7 @@ certificate.">
         assert bytes(dtdfile) == b'<!ENTITY test.me "bananas for sale">\n'
 
     def test_missing_quotes(self, recwarn):
-        """test that we fail graacefully when a message without quotes is found (bug #161)"""
+        """test that we fail gracefully when a message without quotes is found (bug #161)"""
         dtdsource = '<!ENTITY bad no quotes">\n<!ENTITY good "correct quotes">\n'
         dtdfile = self.dtdparse(dtdsource)
         assert len(dtdfile.units) == 1
@@ -435,7 +436,8 @@ certificate.">
 class TestAndroidDTD(test_monolingual.TestMonolingualStore):
     StoreClass = dtd.dtdfile
 
-    def dtdparse(self, dtdsource):
+    @staticmethod
+    def dtdparse(dtdsource):
         """Parses an Android DTD source string and returns a DTD store.
 
         This allows to simulate reading from Android DTD files without really
