@@ -1,10 +1,8 @@
-#!/usr/bin/env python
-
 from translate.storage import ts
 
 
 class TestTS:
-
-    def test_construct(self):
+    @staticmethod
+    def test_construct():
         tsfile = ts.QtTsParser()
         tsfile.addtranslation("ryan", "Bread", "Brood", "Wit", createifmissing=True)
