@@ -18,11 +18,11 @@ class TestTxtFile(test_monolingual.TestMonolingualStore):
 
     def txtregen(self, txtsource, no_segmentation=False):
         """helper that converts txt source to txtfile object and back"""
-        return bytes(self.txtparse(txtsource, no_segmentation)).decode('utf-8')
+        return bytes(self.txtparse(txtsource, no_segmentation)).decode("utf-8")
 
     def test_simpleblock(self):
         """checks that a simple txt block is parsed correctly"""
-        txtsource = 'bananas for sale'
+        txtsource = "bananas for sale"
         txtfile = self.txtparse(txtsource)
         assert len(txtfile.units) == 1
         assert txtfile.units[0].source == txtsource
@@ -30,13 +30,13 @@ class TestTxtFile(test_monolingual.TestMonolingualStore):
 
     def test_multipleblocks(self):
         """check that multiple blocks are parsed correctly"""
-        txtsource = '''One\nOne\n\nTwo\n---\n\nThree'''
+        txtsource = """One\nOne\n\nTwo\n---\n\nThree"""
         txtfile = self.txtparse(txtsource)
         assert len(txtfile.units) == 3
         print(txtsource)
         print(bytes(txtfile))
         print("*%s*" % txtfile.units[0])
-        assert bytes(txtfile).decode('utf-8') == txtsource
+        assert bytes(txtfile).decode("utf-8") == txtsource
         assert self.txtregen(txtsource) == txtsource
 
     def test_no_segmentation(self):
