@@ -50,7 +50,7 @@ class TestXLIFFUnit(test_base.TestTranslationUnit):
     def test_accepted_control_chars(self):
         """Tests we can assign the accepted control chars.
 
-        Source: https://en.wikipedia.org/wiki/Valid_characters_in_XML#XML_1.0
+        Source: :wp:`Valid_characters_in_XML#XML_1.0`
         """
         # Unicode Character 'CHARACTER TABULATION' (U+0009)
         self.unit.target = "Een\t"
@@ -65,7 +65,7 @@ class TestXLIFFUnit(test_base.TestTranslationUnit):
     def test_unaccepted_control_chars(self):
         """Tests we cannot assign the unaccepted control chars without escaping.
 
-        Source: https://en.wikipedia.org/wiki/Valid_characters_in_XML#XML_1.0
+        Source: :wp:`Valid_characters_in_XML#XML_1.0`
         """
         for code in xliff.ASCII_CONTROL_CODES:
             self.unit.target = "Een&#x%s;" % code.lstrip("0") or "0"
@@ -94,7 +94,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         </file>
 </xliff>"""
 
-    def test_basic(self):
+    @staticmethod
+    def test_basic():
         xlifffile = xliff.xlifffile()
         assert xlifffile.units == []
         xlifffile.addsourceunit("Bla")
@@ -106,7 +107,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert newfile.findunit("Bla").source == "Bla"
         assert newfile.findunit("dit") is None
 
-    def test_namespace(self):
+    @staticmethod
+    def test_namespace():
         """Check that we handle namespaces other than the default correctly."""
         xlfsource = """<?xml version="1.0" encoding="utf-8"?>
 <xliff:xliff version="1.2" xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
@@ -122,7 +124,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         print(bytes(xlifffile))
         assert xlifffile.units[0].source == "File 1"
 
-    def test_rich_source(self):
+    @staticmethod
+    def test_rich_source():
         xlifffile = xliff.xlifffile()
         xliffunit = xlifffile.addsourceunit("")
 
@@ -171,7 +174,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
             StringElem(["foobaz", G(id="oof", sub=[G(id="zab", sub=["barrab"])])])
         ]
 
-    def test_rich_target(self):
+    @staticmethod
+    def test_rich_target():
         xlifffile = xliff.xlifffile()
         xliffunit = xlifffile.addsourceunit("")
 
@@ -186,6 +190,11 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert x_placeable.tail == "baz"
 
         # Test 2
+        xliffunit.target = "test plain target"
+        xliffunit.set_rich_target(
+            [StringElem(["foo", G(id="eek", sub=[G(id="ook", sub=["bar", "rab"])])])],
+            "fr",
+        )
         xliffunit.set_rich_target(
             [
                 StringElem(
@@ -201,9 +210,7 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert target_dom_node.text == "foobaz"
 
         assert g_placeable.tag == "g"
-        print(
-            "g_placeable.text: {} ({})".format(g_placeable.text, type(g_placeable.text))
-        )
+        print(f"g_placeable.text: {g_placeable.text} ({type(g_placeable.text)})")
         assert g_placeable.text is None
         assert g_placeable.attrib["id"] == "oof"
         assert g_placeable.tail is None
@@ -217,8 +224,24 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert xliffunit.rich_target == [
             StringElem(["foobaz", G(id="oof", sub=[G(id="zab", sub=["barrab"])])])
         ]
+        print(bytes(xlifffile).decode())
+        assert (
+            bytes(xlifffile).decode()
+            == """<?xml version="1.0" encoding="UTF-8"?>
+<xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
+  <file original="NoName" source-language="en" datatype="plaintext">
+    <body>
+      <trans-unit xml:space="preserve" id="2" approved="yes"><source></source>
+        <target state="translated">foobaz<g id="oof"><g id="zab">barrab</g></g></target>
+      </trans-unit>
+    </body>
+  </file>
+</xliff>
+"""
+        )
 
-    def test_source(self):
+    @staticmethod
+    def test_source():
         xlifffile = xliff.xlifffile()
         xliffunit = xlifffile.addsourceunit("Concept")
         xliffunit.source = "Term"
@@ -227,7 +250,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert newfile.findunit("Concept") is None
         assert newfile.findunit("Term") is not None
 
-    def test_target(self):
+    @staticmethod
+    def test_target():
         xlifffile = xliff.xlifffile()
         xliffunit = xlifffile.addsourceunit("Concept")
         xliffunit.target = "Konsep"
@@ -235,21 +259,24 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         print(bytes(xlifffile))
         assert newfile.findunit("Concept").target == "Konsep"
 
-    def test_sourcelanguage(self):
+    @staticmethod
+    def test_sourcelanguage():
         xlifffile = xliff.xlifffile(sourcelanguage="xh")
         xmltext = bytes(xlifffile).decode("utf-8")
         print(xmltext)
         assert xmltext.find('source-language="xh"') > 0
         # TODO: test that it also works for new files.
 
-    def test_targetlanguage(self):
+    @staticmethod
+    def test_targetlanguage():
         xlifffile = xliff.xlifffile(sourcelanguage="zu", targetlanguage="af")
         xmltext = bytes(xlifffile).decode("utf-8")
         print(xmltext)
         assert xmltext.find('source-language="zu"') > 0
         assert xmltext.find('target-language="af"') > 0
 
-    def test_targetlanguage_multi(self):
+    @staticmethod
+    def test_targetlanguage_multi():
         xlfsource = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE foo [ <!ELEMENT foo ANY > <!ENTITY xxe SYSTEM "file:///etc/passwd" >]>
 <xliff version="1.1" xmlns="urn:oasis:names:tc:xliff:document:1.1">
@@ -266,7 +293,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert xmltext.count('source-language="de"') == 2
         assert xmltext.count('target-language="cs"') == 2
 
-    def test_notes(self):
+    @staticmethod
+    def test_notes():
         xlifffile = xliff.xlifffile()
         unit = xlifffile.addsourceunit("Concept")
         # We don't want to add unnecessary notes
@@ -308,7 +336,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert unit.correctorigin(notenodes[2], "ad")
         assert not unit.correctorigin(notenodes[2], "om")
 
-    def test_alttrans(self):
+    @staticmethod
+    def test_alttrans():
         """Test xliff <alt-trans> accessors"""
         xlifffile = xliff.xlifffile()
         unit = xlifffile.addsourceunit("Testing")
@@ -357,7 +386,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
             < unitformat.find("<alt-trans")
         )
 
-    def test_fuzzy(self):
+    @staticmethod
+    def test_fuzzy():
         xlifffile = xliff.xlifffile()
         unit = xlifffile.addsourceunit("Concept")
         unit.markfuzzy()
@@ -469,7 +499,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         xlifffile = xliff.xlifffile.parsestring(xlfsource)
         assert xlifffile.units[0].istranslatable()
 
-    def test_entities(self):
+    @staticmethod
+    def test_entities():
         xlfsource = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE foo [ <!ELEMENT foo ANY > <!ENTITY xxe SYSTEM "file:///etc/passwd" >]>
 <xliff version="1.1" xmlns="urn:oasis:names:tc:xliff:document:1.1">
@@ -492,7 +523,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert xlifffile.units[1].istranslatable()
         assert xlifffile.units[1].source == "&"
 
-    def test_multiple_filenodes(self):
+    @staticmethod
+    def test_multiple_filenodes():
         xlfsource = """<?xml version="1.0" encoding="utf-8"?>
 <xliff version="1.1" xmlns="urn:oasis:names:tc:xliff:document:1.1">
   <file original="file0" source-language="en" datatype="plaintext">
@@ -532,8 +564,9 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert newxfile.getfilenode("file1") is not None
         assert not newxfile.getfilenode("foo")
 
-    def test_indent(self):
-        xlfsource = b"""<?xml version='1.0' encoding='UTF-8'?>
+    @staticmethod
+    def test_indent():
+        xlfsource = b"""<?xml version="1.0" encoding="UTF-8"?>
 <xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
   <file original="doc.txt" source-language="en-US">
     <body>
@@ -545,7 +578,7 @@ class TestXLIFFfile(test_base.TestTranslationStore):
   </file>
 </xliff>
 """
-        xlfsourcenote = b"""<?xml version='1.0' encoding='UTF-8'?>
+        xlfsourcenote = b"""<?xml version="1.0" encoding="UTF-8"?>
 <xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
   <file original="doc.txt" source-language="en-US">
     <body>
@@ -563,8 +596,9 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         xfile.units[0].addnote("Test note")
         assert bytes(xfile) == xlfsourcenote
 
-    def test_add_target(self):
-        xlfsource = b"""<?xml version='1.0' encoding='UTF-8'?>
+    @staticmethod
+    def test_add_target():
+        xlfsource = b"""<?xml version="1.0" encoding="UTF-8"?>
 <xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
   <file original="doc.txt" source-language="en-US">
     <body>
@@ -574,7 +608,7 @@ class TestXLIFFfile(test_base.TestTranslationStore):
   </file>
 </xliff>
 """
-        xlftarget = """<?xml version='1.0' encoding='UTF-8'?>
+        xlftarget = """<?xml version="1.0" encoding="UTF-8"?>
 <xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
   <file original="doc.txt" source-language="en-US">
     <body>
@@ -590,8 +624,9 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         xfile.units[0].rich_target = ["Soubor"]
         assert bytes(xfile).decode("ascii") == xlftarget
 
-    def test_preserve(self):
-        xlfsource = """<?xml version='1.0' encoding='UTF-8'?>
+    @staticmethod
+    def test_preserve():
+        xlfsource = """<?xml version="1.0" encoding="UTF-8"?>
 <xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
   <file original="doc.txt" source-language="en-US">
     <body>
