@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2005-2009 Zuza Software Foundation
 #
@@ -22,7 +21,7 @@
 from lxml import etree
 
 from translate import __version__
-from translate.misc.xml_helpers import setXMLlang
+from translate.misc.xml_helpers import setXMLlang, valid_chars_only
 from translate.storage import lisa
 
 
@@ -35,14 +34,17 @@ class tmxunit(lisa.LISAunit):
 
     def createlanguageNode(self, lang, text, purpose):
         """returns a langset xml Element setup with given parameters"""
-        if isinstance(text, bytes):
-            text = text.decode("utf-8")
         langset = etree.Element(self.languageNode)
         setXMLlang(langset, lang)
         seg = etree.SubElement(langset, self.textNode)
         # implied by the standard:
         # setXMLspace(seg, "preserve")
-        seg.text = text
+        try:
+            seg.text = text
+        except ValueError:
+            # Prevents "All strings must be XML compatible" when string contains a control characters
+            seg.text = valid_chars_only(text)
+
         return langset
 
     def getid(self):
@@ -51,7 +53,7 @@ class tmxunit(lisa.LISAunit):
         property is only mandated to be unique from TMX 2.0.
         """
         id = self.xmlelement.get("tuid", "")
-        return id or super(tmxunit, self).getid()
+        return id or super().getid()
 
     def istranslatable(self):
         return bool(self.source)
@@ -61,8 +63,6 @@ class tmxunit(lisa.LISAunit):
 
         The origin parameter is ignored
         """
-        if isinstance(text, bytes):
-            text = text.decode("utf-8")
         note = etree.SubElement(self.xmlelement, self.namespaced("note"))
         note.text = text.strip()
 
@@ -74,12 +74,10 @@ class tmxunit(lisa.LISAunit):
         :rtype: List
         """
         note_nodes = self.xmlelement.iterdescendants(self.namespaced("note"))
-        note_list = [lisa.getText(note) for note in note_nodes]
-
-        return note_list
+        return [lisa.getText(note) for note in note_nodes]
 
     def getnotes(self, origin=None):
-        return '\n'.join(self._getnotelist(origin=origin))
+        return "\n".join(self._getnotelist(origin=origin))
 
     def removenotes(self, origin=None):
         """Remove all the translator notes."""
@@ -92,7 +90,7 @@ class tmxunit(lisa.LISAunit):
         # TODO: consider factoring out: some duplication between XLIFF and TMX
         text = errorname
         if errortext:
-            text += ': ' + errortext
+            text += ": " + errortext
         self.addnote(text, origin="pofilter")
 
     def geterrors(self):
@@ -101,7 +99,7 @@ class tmxunit(lisa.LISAunit):
         notelist = self._getnotelist(origin="pofilter")
         errordict = {}
         for note in notelist:
-            errorname, errortext = note.split(': ')
+            errorname, errortext = note.split(": ")
             errordict[errorname] = errortext
         return errordict
 
@@ -126,15 +124,17 @@ class tmxfile(lisa.LISAfile):
     Extensions = ["tmx"]
     rootNode = "tmx"
     bodyNode = "body"
-    XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
+    XMLskeleton = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE tmx SYSTEM "tmx14.dtd">
 <tmx version="1.4">
 <header></header>
 <body></body>
-</tmx>'''
+</tmx>"""
 
     def addheader(self):
-        headernode = next(self.document.getroot().iterchildren(self.namespaced("header")))
+        headernode = next(
+            self.document.getroot().iterchildren(self.namespaced("header"))
+        )
         headernode.set("creationtool", "Translate Toolkit")
         headernode.set("creationtoolversion", __version__.sver)
         headernode.set("segtype", "sentence")
@@ -144,18 +144,17 @@ class tmxfile(lisa.LISAfile):
         # targetlanguage
         headernode.set("srclang", self.sourcelanguage)
         headernode.set("datatype", "PlainText")
-        #headernode.set("creationdate", "YYYYMMDDTHHMMSSZ"
-        #headernode.set("creationid", "CodeSyntax"
+        # headernode.set("creationdate", "YYYYMMDDTHHMMSSZ"
+        # headernode.set("creationid", "CodeSyntax"
 
-    def addtranslation(self, source, srclang, translation, translang,
-                       comment=None):
+    def addtranslation(self, source, srclang, translation, translang, comment=None):
         """addtranslation method for testing old unit tests"""
         unit = self.addsourceunit(source)
         unit.target = translation
         if comment is not None and len(comment) > 0:
             unit.addnote(comment)
 
-        tuvs = unit.xmlelement.iterdescendants(self.namespaced('tuv'))
+        tuvs = unit.xmlelement.iterdescendants(self.namespaced("tuv"))
         setXMLlang(next(tuvs), srclang)
         setXMLlang(next(tuvs), translang)
 
