@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2010 Zuza Software Foundation
 #
@@ -78,30 +77,46 @@ Extended Attributes
     The last 4 columns allow users to define and manage extended attributes.
     These are left as is and are not directly managed byour implemenation.
 """
-from __future__ import unicode_literals
 
-import six
+import csv
 import time
 
-if six.PY2:
-    from backports import csv
-else:
-    import csv
-
-from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
 WF_TIMEFORMAT = "%Y%m%d~%H%M%S"
 """Time format used by Wordfast"""
 
-WF_FIELDNAMES_HEADER = ["date", "userlist", "tucount", "src-lang", "version",
-                        "target-lang", "license", "attr1list", "attr2list",
-                        "attr3list", "attr4list", "attr5list"]
+WF_FIELDNAMES_HEADER = [
+    "date",
+    "userlist",
+    "tucount",
+    "src-lang",
+    "version",
+    "target-lang",
+    "license",
+    "attr1list",
+    "attr2list",
+    "attr3list",
+    "attr4list",
+    "attr5list",
+]
 """Field names for the Wordfast header"""
 
-WF_FIELDNAMES = ["date", "user", "reuse", "src-lang", "source", "target-lang",
-                 "target", "attr1", "attr2", "attr3", "attr4"]
+WF_FIELDNAMES = [
+    "date",
+    "user",
+    "reuse",
+    "src-lang",
+    "source",
+    "target-lang",
+    "target",
+    "attr1",
+    "attr2",
+    "attr3",
+    "attr4",
+    "attr5",
+]
 """Field names for a Wordfast TU"""
 
 WF_FIELDNAMES_HEADER_DEFAULTS = {
@@ -125,43 +140,43 @@ WF_FIELDNAMES_HEADER_DEFAULTS = {
 # For now these look correct and have been taken from Windows CP1252 and
 # Macintosh code points found for the respective character sets on Linux.
 WF_ESCAPE_MAP = (
-    ("&'26;", u"\u0026"),  # & - Ampersand (must be first to prevent
-                           #     escaping of escapes)
-    ("&'82;", u"\u201A"),  # ‚ - Single low-9 quotation mark
-    ("&'85;", u"\u2026"),  # … - Elippsis
-    ("&'91;", u"\u2018"),  # ‘ - left single quotation mark
-    ("&'92;", u"\u2019"),  # ’ - right single quotation mark
-    ("&'93;", u"\u201C"),  # “ - left double quotation mark
-    ("&'94;", u"\u201D"),  # ” - right double quotation mark
-    ("&'96;", u"\u2013"),  # – - en dash (validate)
-    ("&'97;", u"\u2014"),  # — - em dash (validate)
-    ("&'99;", u"\u2122"),  # ™ - Trade mark
+    ("&'26;", "\u0026"),  # & - Ampersand (must be first to prevent
+    #     escaping of escapes)
+    ("&'82;", "\u201A"),  # ‚ - Single low-9 quotation mark
+    ("&'85;", "\u2026"),  # … - Elippsis
+    ("&'91;", "\u2018"),  # ‘ - left single quotation mark
+    ("&'92;", "\u2019"),  # ’ - right single quotation mark
+    ("&'93;", "\u201C"),  # “ - left double quotation mark
+    ("&'94;", "\u201D"),  # ” - right double quotation mark
+    ("&'96;", "\u2013"),  # – - en dash (validate)
+    ("&'97;", "\u2014"),  # — - em dash (validate)
+    ("&'99;", "\u2122"),  # ™ - Trade mark
     # Windows only
-    ("&'A0;", u"\u00A0"),  #   - Non breaking space
-    ("&'A9;", u"\u00A9"),  # © - Copyright
-    ("&'AE;", u"\u00AE"),  # ® - Registered
-    ("&'BC;", u"\u00BC"),  # ¼
-    ("&'BD;", u"\u00BD"),  # ½
-    ("&'BE;", u"\u00BE"),  # ¾
+    ("&'A0;", "\u00A0"),  #   - Non breaking space
+    ("&'A9;", "\u00A9"),  # © - Copyright
+    ("&'AE;", "\u00AE"),  # ® - Registered
+    ("&'BC;", "\u00BC"),  # ¼
+    ("&'BD;", "\u00BD"),  # ½
+    ("&'BE;", "\u00BE"),  # ¾
     # Mac only
-    ("&'A8;", u"\u00AE"),  # ® - Registered
-    ("&'AA;", u"\u2122"),  # ™ - Trade mark
-    ("&'C7;", u"\u00AB"),  # « - Left-pointing double angle quotation mark
-    ("&'C8;", u"\u00BB"),  # » - Right-pointing double angle quotation mark
-    ("&'C9;", u"\u2026"),  # … - Horizontal Elippsis
-    ("&'CA;", u"\u00A0"),  #   - Non breaking space
-    ("&'D0;", u"\u2013"),  # – - en dash (validate)
-    ("&'D1;", u"\u2014"),  # — - em dash (validate)
-    ("&'D2;", u"\u201C"),  # “ - left double quotation mark
-    ("&'D3;", u"\u201D"),  # ” - right double quotation mark
-    ("&'D4;", u"\u2018"),  # ‘ - left single quotation mark
-    ("&'D5;", u"\u2019"),  # ’ - right single quotation mark
-    ("&'E2;", u"\u201A"),  # ‚ - Single low-9 quotation mark
-    ("&'E3;", u"\u201E"),  # „ - Double low-9 quotation mark
+    ("&'A8;", "\u00AE"),  # ® - Registered
+    ("&'AA;", "\u2122"),  # ™ - Trade mark
+    ("&'C7;", "\u00AB"),  # « - Left-pointing double angle quotation mark
+    ("&'C8;", "\u00BB"),  # » - Right-pointing double angle quotation mark
+    ("&'C9;", "\u2026"),  # … - Horizontal Elippsis
+    ("&'CA;", "\u00A0"),  #   - Non breaking space
+    ("&'D0;", "\u2013"),  # – - en dash (validate)
+    ("&'D1;", "\u2014"),  # — - em dash (validate)
+    ("&'D2;", "\u201C"),  # “ - left double quotation mark
+    ("&'D3;", "\u201D"),  # ” - right double quotation mark
+    ("&'D4;", "\u2018"),  # ‘ - left single quotation mark
+    ("&'D5;", "\u2019"),  # ’ - right single quotation mark
+    ("&'E2;", "\u201A"),  # ‚ - Single low-9 quotation mark
+    ("&'E3;", "\u201E"),  # „ - Double low-9 quotation mark
     # Other markers
     # Soft-break - XXX creates a problem with roundtripping could
     # also be represented by \u2028
-    #("&'B;", u"\n"),
+    # ("&'B;", "\n"),
 )
 """Mapping of Wordfast &'XX; escapes to correct Unicode characters"""
 
@@ -204,14 +219,14 @@ class WordfastDialect(csv.Dialect):
 csv.register_dialect("wordfast", WordfastDialect)
 
 
-class WordfastTime(object):
+class WordfastTime:
     """Manages time stamps in the Wordfast format of YYYYMMDD~hhmmss"""
 
     def __init__(self, newtime=None):
         self._time = None
         if not newtime:
             self.time = None
-        elif isinstance(newtime, six.string_types):
+        elif isinstance(newtime, str):
             self.timestring = newtime
         elif isinstance(newtime, time.struct_time):
             self.time = newtime
@@ -230,6 +245,7 @@ class WordfastTime(object):
         :type timestring: String
         """
         self._time = time.strptime(timestring, WF_TIMEFORMAT)
+
     timestring = property(get_timestring, set_timestring)
 
     def get_time(self):
@@ -246,6 +262,7 @@ class WordfastTime(object):
             self._time = newtime
         else:
             self._time = None
+
     time = property(get_time, set_time)
 
     def __str__(self):
@@ -255,7 +272,7 @@ class WordfastTime(object):
             return self.timestring
 
 
-class WordfastHeader(object):
+class WordfastHeader:
     """A wordfast translation memory header"""
 
     def __init__(self, header=None):
@@ -265,12 +282,14 @@ class WordfastHeader(object):
         elif isinstance(header, dict):
             self.header = header
 
-    def _create_default_header(self):
+    @staticmethod
+    def _create_default_header():
         """Create a default Wordfast header with the date set to the current
         time
         """
-        defaultheader = WF_FIELDNAMES_HEADER_DEFAULTS
-        defaultheader['date'] = '%%%s' % WordfastTime(time.localtime()).timestring
+        defaultheader = {}
+        defaultheader.update(WF_FIELDNAMES_HEADER_DEFAULTS)
+        defaultheader["date"] = "%%%s" % WordfastTime(time.localtime()).timestring
         return defaultheader
 
     def getheader(self):
@@ -279,18 +298,20 @@ class WordfastHeader(object):
 
     def setheader(self, newheader):
         self._header_dict = newheader
+
     header = property(getheader, setheader)
 
     def settargetlang(self, newlang):
-        self._header_dict['target-lang'] = '%%%s' % newlang
+        self._header_dict["target-lang"] = "%%%s" % newlang
+
     targetlang = property(None, settargetlang)
 
     def settucount(self, count):
-        self._header_dict['tucount'] = '%%TU=%08d' % count
+        self._header_dict["tucount"] = "%%TU=%08d" % count
+
     tucount = property(None, settucount)
 
 
-@six.python_2_unicode_compatible
 class WordfastUnit(base.TranslationUnit):
     """A Wordfast translation memory unit"""
 
@@ -298,11 +319,11 @@ class WordfastUnit(base.TranslationUnit):
         self._dict = {}
         if source:
             self.source = source
-        super(WordfastUnit, self).__init__(source)
+        super().__init__(source)
 
     def _update_timestamp(self):
         """Refresh the timestamp for the unit"""
-        self._dict['date'] = WordfastTime(time.localtime()).timestring
+        self._dict["date"] = WordfastTime(time.localtime()).timestring
 
     def getdict(self):
         """Get the dictionary of values for a Wordfast line"""
@@ -316,6 +337,7 @@ class WordfastUnit(base.TranslationUnit):
         """
         # TODO First check that the values are OK
         self._dict = newdict
+
     dict = property(getdict, setdict)
 
     def _get_source_or_target(self, key):
@@ -336,43 +358,34 @@ class WordfastUnit(base.TranslationUnit):
 
     @property
     def source(self):
-        return self._get_source_or_target('source')
+        return self._get_source_or_target("source")
 
     @source.setter
     def source(self, source):
         self._rich_source = None
-        self._set_source_or_target('source', source)
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
+        self._set_source_or_target("source", source)
 
     @property
     def target(self):
-        return self._get_source_or_target('target')
+        return self._get_source_or_target("target")
 
     @target.setter
     def target(self, target):
         self._rich_target = None
-        self._set_source_or_target('target', target)
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
+        self._set_source_or_target("target", target)
 
     def settargetlang(self, newlang):
-        self._dict['target-lang'] = newlang
+        self._dict["target-lang"] = newlang
+
     targetlang = property(None, settargetlang)
 
     def __str__(self):
         return str(self._dict)
 
     def istranslated(self):
-        if not self._dict.get('source', None):
+        if not self._dict.get("source", None):
             return False
-        return bool(self._dict.get('target', None))
+        return bool(self._dict.get("target", None))
 
 
 class WordfastTMFile(base.TranslationStore):
@@ -382,38 +395,44 @@ class WordfastTMFile(base.TranslationStore):
     Mimetypes = ["application/x-wordfast"]
     Extensions = ["txt"]
     UnitClass = WordfastUnit
-    default_encoding = 'iso-8859-1'
+    default_encoding = "iso-8859-1"
 
     def __init__(self, inputfile=None, **kwargs):
         """construct a Wordfast TM, optionally reading in from inputfile."""
-        super(WordfastTMFile, self).__init__(**kwargs)
-        self.filename = ''
+        super().__init__(**kwargs)
+        self.filename = ""
         self.header = WordfastHeader()
         if inputfile is not None:
             self.parse(inputfile)
 
     def parse(self, input):
         """parsese the given file or file source string"""
-        if hasattr(input, 'name'):
+        if hasattr(input, "name"):
             self.filename = input.name
-        elif not getattr(self, 'filename', ''):
-            self.filename = ''
+        elif not getattr(self, "filename", ""):
+            self.filename = ""
         if hasattr(input, "read"):
             tmsrc = input.read()
             input.close()
             input = tmsrc
         if TAB_UTF16 in input.split(b"\n")[0]:
-            self.encoding = 'utf-16'
+            self.encoding = "utf-16"
         else:
-            self.encoding = 'iso-8859-1'
+            self.encoding = "iso-8859-1"
         try:
             input = input.decode(self.encoding)
         except Exception:
-            raise ValueError("Wordfast files are either UTF-16 (UCS2) or ISO-8859-1 encoded")
-        reader = csv.DictReader(input.split("\n"), fieldnames=WF_FIELDNAMES, dialect="wordfast")
+            raise ValueError(
+                "Wordfast files are either UTF-16 (UCS2) or ISO-8859-1 encoded"
+            )
+        reader = csv.DictReader(
+            input.split("\n"), fieldnames=WF_FIELDNAMES, dialect="wordfast"
+        )
         for idx, line in enumerate(reader):
             if idx == 0:
-                header = dict(zip(WF_FIELDNAMES_HEADER, [line[key] for key in WF_FIELDNAMES]))
+                header = dict(
+                    zip(WF_FIELDNAMES_HEADER, [line[key] for key in WF_FIELDNAMES])
+                )
                 self.header = WordfastHeader(header)
                 continue
             newunit = WordfastUnit()
@@ -430,7 +449,14 @@ class WordfastTMFile(base.TranslationStore):
         writer = csv.DictWriter(output, fieldnames=WF_FIELDNAMES, dialect="wordfast")
         # No real headers, the first line contains metadata
         self.header.tucount = len(translated_units)
-        writer.writerow(dict(zip(WF_FIELDNAMES, [self.header.header[key] for key in WF_FIELDNAMES_HEADER])))
+        writer.writerow(
+            dict(
+                zip(
+                    WF_FIELDNAMES,
+                    [self.header.header[key] for key in WF_FIELDNAMES_HEADER],
+                )
+            )
+        )
 
         for unit in translated_units:
             writer.writerow(unit.dict)
