@@ -121,11 +121,6 @@ class YAMLFile(base.DictStore):
     def _parse_dict(self, data, prev):
         # Avoid using merged items, it is enough to have them once
         for k, v in data.non_merged_items():
-            if not isinstance(k, str):
-                raise base.ParseError(
-                    "Key not string: {}/{} ({})".format(prev, k, type(k))
-                )
-
             yield from self._flatten(v, prev + [("key", k)])
 
     def _flatten(self, data, prev=None):
@@ -154,7 +149,8 @@ class YAMLFile(base.DictStore):
                     "Previous: %s" % (type(data), data, prev)
                 )
 
-    def preprocess(self, data):
+    @staticmethod
+    def preprocess(data):
         """Preprocess hook for child formats"""
         return data
 
@@ -218,6 +214,8 @@ class RubyYAMLFile(YAMLFile):
         if isinstance(data, CommentedMap) and len(data) == 1:
             lang = list(data.keys())[0]
             self.settargetlanguage(lang)
+            if data[lang] is None:
+                data[lang] = CommentedMap()
             return data[lang]
         return data
 
