@@ -1,4 +1,3 @@
-import warnings
 from io import BytesIO
 
 from pytest import mark
@@ -18,13 +17,8 @@ class TestPretranslate:
         </file>
 </xliff>"""
 
-    def setup_method(self, method):
-        warnings.resetwarnings()
-
-    def teardown_method(self, method):
-        warnings.resetwarnings()
-
-    def pretranslatepo(self, input_source, template_source=None):
+    @staticmethod
+    def pretranslatepo(input_source, template_source=None):
         """helper that converts strings to po source without requiring files"""
         input_file = BytesIO(input_source.encode())
         if template_source:
@@ -37,7 +31,8 @@ class TestPretranslate:
         output_file.seek(0)
         return po.pofile(output_file.read())
 
-    def pretranslatexliff(self, input_source, template_source=None):
+    @staticmethod
+    def pretranslatexliff(input_source, template_source=None):
         """helper that converts strings to po source without requiring files"""
         input_file = BytesIO(input_source)
         if template_source:
@@ -50,7 +45,8 @@ class TestPretranslate:
         output_file.seek(0)
         return xliff.xlifffile(output_file.read())
 
-    def singleunit(self, pofile):
+    @staticmethod
+    def singleunit(pofile):
         """
         checks that the pofile contains a single non-header unit, and
         returns it
